@@ -29,8 +29,6 @@ Engine::Engine()
     add("set_random_seed", &Engine::cmd_set_random_seed);
 }
 
-Engine::~Engine() = default;
-
 void Engine::cmd_cputime(Response& response)
 {
     double time = libboardgame_sys::cpu_time();
@@ -42,7 +40,7 @@ void Engine::cmd_cputime(Response& response)
 /** Set global random seed.
     Compatible with @ref libboardgame_doc_gnugo <br>
     Arguments: random seed */
-void Engine::cmd_set_random_seed(const Arguments& args)
+void Engine::cmd_set_random_seed(Arguments args)
 {
     RandomGenerator::set_global_seed(args.parse<RandomGenerator::ResultType>());
 }
