@@ -20,13 +20,11 @@ class Engine
     : public libboardgame_gtp::Engine
 {
 public:
-    void cmd_cputime(Response&);
-    void cmd_set_random_seed(const Arguments&);
+    void cmd_cputime(Response& response);
+    void cmd_set_random_seed(Arguments args);
 
     Engine();
 
-    ~Engine();
-
 protected:
     void on_handle_cmd_begin() override;
 };
