@@ -31,23 +31,27 @@ template<class P>
 class Geometry
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    typedef typename Point::IntType IntType;
+    using IntType = typename Point::IntType;
+
+    static const unsigned max_adj = 4;
+
+    static const unsigned max_diag = 11;
 
     /** On-board adjacent neighbors of a point. */
-    typedef ArrayList<Point, 4, unsigned short> AdjList;
+    using AdjList = ArrayList<Point, max_adj, unsigned short>;
 
     /** On-board diagonal neighbors of a point
         Currently supports up to 11 diagonal points as used on boards
         for GembloQ. */
-    typedef ArrayList<Point, 11, unsigned short> DiagList;
+    using DiagList = ArrayList<Point, max_diag, unsigned short>;
 
     /** Adjacent neighbors of a coordinate. */
-    typedef ArrayList<CoordPoint, 4> AdjCoordList;
+    using AdjCoordList = ArrayList<CoordPoint, max_adj>;
 
     /** Diagonal neighbors of a coordinate. */
-    typedef ArrayList<CoordPoint, 11> DiagCoordList;
+    using DiagCoordList = ArrayList<CoordPoint, max_diag>;
 
     class Iterator
     {
@@ -105,10 +109,10 @@ public:
 
     unsigned get_point_type(Point p) const;
 
-    bool is_onboard(unsigned x, unsigned y) const;
-
     bool is_onboard(CoordPoint p) const;
 
+    bool is_onboard(int x, int y) const { return is_onboard(CoordPoint(x, y)); }
+
     /** Return the point at a given coordinate.
         @pre x < get_width()
         @pre y < get_height()
@@ -127,7 +131,8 @@ public:
 
     unsigned get_y(Point p) const;
 
-    bool from_string(const string& s, Point& p) const;
+    bool from_string(string::const_iterator begin, string::const_iterator end,
+                     Point& p) const;
 
     const string& to_string(Point p) const;
 
@@ -136,8 +141,7 @@ public:
     const DiagList& get_diag(Point p) const;
 
 protected:
-    explicit Geometry(unique_ptr<StringRep> string_rep =
-                          unique_ptr<StringRep>(new StdStringRep));
+    explicit Geometry(unique_ptr<StringRep> string_rep = make_unique<StdStringRep>());
 
     /** Initialize.
         Subclasses must call this function in their constructors. */
@@ -185,21 +189,19 @@ Geometry<P>::Geometry(unique_ptr<StringRep> string_rep)
 { }
 
 template<class P>
-Geometry<P>::~Geometry() = default;
+Geometry<P>::~Geometry() = default; // Non-inline to avoid GCC -Winline warning
 
 template<class P>
-bool Geometry<P>::from_string(const string& s, Point& p) const
+bool Geometry<P>::from_string(string::const_iterator begin,
+                              string::const_iterator end, Point& p) const
 {
-    istringstream in(s);
     unsigned x;
     unsigned y;
-    if (m_string_rep->read(in, m_width, m_height, x, y)
-            && is_onboard(CoordPoint(x, y)))
-    {
-        p = get_point(x, y);
-        return true;
-    }
-    return false;
+    if (! m_string_rep->read(begin, end, m_width, m_height, x, y)
+            || ! is_onboard(x, y))
+        return false;
+    p = get_point(x, y);
+    return true;
 }
 
 template<class P>
@@ -293,16 +295,10 @@ void Geometry<P>::init(unsigned width, unsigned height)
     }
 }
 
-template<class P>
-inline bool Geometry<P>::is_onboard(unsigned x, unsigned y) const
-{
-    return ! get_point(x, y).is_null();
-}
-
 template<class P>
 bool Geometry<P>::is_onboard(CoordPoint p) const
 {
-    return p.is_onboard(m_width, m_height) && is_onboard(p.x, p.y);
+    return p.is_onboard(m_width, m_height) && ! get_point(p.x, p.y).is_null();
 }
 
 #if LIBBOARDGAME_DEBUG
