@@ -68,9 +68,10 @@ class Grid
     friend class GridExt<P, T>; // for GridExt::copy_from(Grid)
 
 public:
-    typedef P Point;
+    using Point = P;
+
+    using Geometry = libboardgame_base::Geometry<P>;
 
-    typedef libboardgame_base::Geometry<P> Geometry;
 
     T& operator[](const Point& p);
 
@@ -96,6 +97,7 @@ private:
     T m_a[Point::range_onboard];
 };
 
+
 template<class P, typename T>
 inline T& Grid<P, T>::operator[](const Point& p)
 {
@@ -150,9 +152,10 @@ template<class P, typename T>
 class GridExt
 {
 public:
-    typedef P Point;
+    using Point = P;
+
+    using Geometry = libboardgame_base::Geometry<P>;
 
-    typedef libboardgame_base::Geometry<P> Geometry;
 
     T& operator[](const Point& p);
 
@@ -174,6 +177,7 @@ private:
     T m_a[Point::range];
 };
 
+
 template<class P, typename T>
 inline T& GridExt<P, T>::operator[](const Point& p)
 {
