@@ -24,7 +24,8 @@ template<class P>
 class Marker
 {
 public:
-    typedef P Point;
+    using Point = P;
+
 
     Marker();
 
@@ -51,6 +52,7 @@ private:
     void reset();
 };
 
+
 template<class P>
 inline Marker<P>::Marker()
 {
