@@ -14,56 +14,56 @@ namespace libboardgame_base {
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfIdentity::get_transformed(const CoordPoint& p) const
+CoordPoint TransfIdentity::get_transformed(CoordPoint p) const
 {
     return p;
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot90::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot90::get_transformed(CoordPoint p) const
 {
     return CoordPoint(-p.y, p.x);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot180::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot180::get_transformed(CoordPoint p) const
 {
     return CoordPoint(-p.x, -p.y);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot270::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot270::get_transformed(CoordPoint p) const
 {
     return CoordPoint(p.y, -p.x);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRefl::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRefl::get_transformed(CoordPoint p) const
 {
     return CoordPoint(-p.x, p.y);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot90Refl::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot90Refl::get_transformed(CoordPoint p) const
 {
     return CoordPoint(-p.y, -p.x);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot180Refl::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot180Refl::get_transformed(CoordPoint p) const
 {
     return CoordPoint(p.x, -p.y);
 }
 
 //-----------------------------------------------------------------------------
 
-CoordPoint TransfRectRot270Refl::get_transformed(const CoordPoint& p) const
+CoordPoint TransfRectRot270Refl::get_transformed(CoordPoint p) const
 {
     return CoordPoint(p.y, p.x);
 }
