@@ -17,9 +17,9 @@ namespace libboardgame_base {
 class Transform
 {
 public:
-    virtual ~Transform();
+    virtual ~Transform() = default;
 
-    virtual CoordPoint get_transformed(const CoordPoint& p) const = 0;
+    virtual CoordPoint get_transformed(CoordPoint p) const = 0;
 
     /** Get the new point type of the (0,0) coordinates.
         The transformation may change the point type of the (0,0) coordinates.
