@@ -169,11 +169,8 @@ string Arguments::get_type_name()
         free(name_ptr);
         return result;
     }
-    else
-        return typeid(T).name();
-#else
-    return typeid(T).name();
 #endif
+    return typeid(T).name();
 }
 
 template<typename T>
@@ -203,7 +200,7 @@ T Arguments::parse(unsigned i) const
 template<typename T>
 T Arguments::parse_min(unsigned i, T min) const
 {
-    T result = parse<T>(i);
+    auto result = parse<T>(i);
     if (result < min)
     {
         ostringstream msg;
