@@ -25,7 +25,7 @@ namespace {
 bool is_cmd_line(const string& line)
 {
     for (char c : line)
-        if (! isspace(static_cast<unsigned char>(c)))
+        if (isspace(static_cast<unsigned char>(c)) == 0)
             return c != '#';
     return false;
 }
@@ -45,8 +45,7 @@ bool read_cmd(CmdLine& c, istream& in)
         c.init(line);
         return true;
     }
-    else
-        return false;
+    return false;
 }
 
 } // namespace
@@ -57,39 +56,42 @@ Engine::Engine()
 {
     add("known_command", &Engine::cmd_known_command);
     add("list_commands", &Engine::cmd_list_commands);
-    add("name", &Engine::cmd_name);
     add("protocol_version", &Engine::cmd_protocol_version);
     add("quit", &Engine::cmd_quit);
-    add("version", &Engine::cmd_version);
 }
 
-Engine::~Engine() = default;
+Engine::~Engine() = default; // Non-inline to avoid GCC -Winline warning
 
-void Engine::add(const string& name, Handler f)
+void Engine::add(const string& name, const Handler& f)
 {
     m_handlers[name] = f;
 }
 
-void Engine::add(const string& name, HandlerNoArgs f)
+void Engine::add(const string& name, const HandlerNoArgs& f)
 {
-    add(name,
-        Handler(bind(no_args_wrapper, f, placeholders::_1, placeholders::_2)));
+    add(name, [f](Arguments args, Response& response) {
+        args.check_empty();
+        f(response);
+    });
 }
 
-void Engine::add(const string& name, HandlerNoResponse f)
+void Engine::add(const string& name, const HandlerNoResponse& f)
 {
-    add(name, Handler(bind(no_response_wrapper, f,
-                           placeholders::_1, placeholders::_2)));
+    add(name, [f](Arguments args, Response&) {
+        f(args);
+    });
 }
 
-void Engine::add(const string& name, HandlerNoArgsNoResponse f)
+void Engine::add(const string& name, const HandlerNoArgsNoResponse& f)
 {
-    add(name, Handler(bind(no_args_no_response_wrapper, f,
-                           placeholders::_1, placeholders::_2)));
+    add(name, [f](Arguments args, Response&) {
+        args.check_empty();
+        f();
+    });
 }
 
 /** Return @c true if command is known, @c false otherwise. */
-void Engine::cmd_known_command(const Arguments& args, Response& response)
+void Engine::cmd_known_command(Arguments args, Response& response)
 {
     response.set(contains(args.get()) ? "true" : "false");
 }
@@ -101,12 +103,6 @@ void Engine::cmd_list_commands(Response& response)
         response << i.first << '\n';
 }
 
-/** Return name. */
-void Engine::cmd_name(Response& response)
-{
-    response.set("Unknown");
-}
-
 /** Return protocol version. */
 void Engine::cmd_protocol_version(Response& response)
 {
@@ -119,13 +115,6 @@ void Engine::cmd_quit()
     m_quit = true;
 }
 
-/** Return empty version string.
-    The GTP standard says to return empty string, if no meaningful response
-    is available. */
-void Engine::cmd_version(Response&)
-{
-}
-
 bool Engine::contains(const string& name) const
 {
     return m_handlers.count(name) > 0;
@@ -142,7 +131,7 @@ bool Engine::exec(istream& in, bool throw_on_fail, ostream* log)
         if (! is_cmd_line(line))
             continue;
         cmd.init(line);
-        if (log)
+        if (log != nullptr)
             *log << cmd.get_line() << '\n';
         bool status = handle_cmd(cmd, log, response, buffer);
         if (! status && throw_on_fail)
@@ -202,7 +191,7 @@ bool Engine::handle_cmd(CmdLine& line, ostream* out, Response& response,
         status = false;
         response.set(failure.what());
     }
-    if (out)
+    if (out != nullptr)
     {
         *out << (status ? '=' : '?');
         line.write_id(*out);
@@ -213,26 +202,6 @@ bool Engine::handle_cmd(CmdLine& line, ostream* out, Response& response,
     return status;
 }
 
-void Engine::no_args_wrapper(HandlerNoArgs h, const Arguments& args,
-                             Response& response)
-{
-    args.check_empty();
-    h(response);
-}
-
-void Engine::no_response_wrapper(HandlerNoResponse h, const Arguments& args,
-                                 Response&)
-{
-    h(args);
-}
-
-void Engine::no_args_no_response_wrapper(HandlerNoArgsNoResponse h,
-                                         const Arguments& args, Response&)
-{
-    args.check_empty();
-    h();
-}
-
 void Engine::on_handle_cmd_begin()
 {
     // Default implementation does nothing
