@@ -13,7 +13,7 @@ namespace libboardgame_mcts {
 
 //-----------------------------------------------------------------------------
 
-typedef uint_fast8_t PlayerInt;
+using PlayerInt = uint_fast8_t;
 
 //-----------------------------------------------------------------------------
 
