@@ -66,7 +66,8 @@ struct SearchParamConstDefault
         the digits in the mantissa (=23 for IEEE 754 float's). The search will
         terminate when this number is reached. For longer searches, the code
         should be compiled with floating type @c double. */
-    typedef float Float;
+    using Float = float;
+
 
     /** The maximum number of players. */
     static const PlayerInt max_players = 2;
@@ -109,7 +110,10 @@ struct SearchParamConstDefault
         The value must be greater 0 (it may be a positive epsilon) because
         otherwise the search would need to handle a special case in the bias
         term computation. */
-    static constexpr Float child_min_count = 0;
+    static constexpr Float child_min_count = 1;
+
+    /** Maximum value used for Node::get_move_prior() */
+    static constexpr Float max_move_prior = 1;
 
     /** An evaluation value representing a 50% winning probability. */
     static constexpr Float tie_value = 0.5f;
@@ -120,10 +124,10 @@ struct SearchParamConstDefault
     static constexpr Float prune_count_start = 16;
 
     /** Minimum count of a node to be expanded. */
-    static constexpr Float expand_threshold = 0;
+    static constexpr Float expansion_threshold = 0;
 
-    /** Increase of the expand threshold per in-tree move played. */
-    static constexpr Float expand_threshold_inc = 0;
+    /** Increase of the expansion threshold per in-tree move played. */
+    static constexpr Float expansion_threshold_inc = 0;
 
     /** Expected simulations per second.
         If the simulations per second vary a lot, it should be a value closer
@@ -151,6 +155,11 @@ struct SearchParamConstDefault
     It is weaker than the original RAVE at a low number of simulations but
     seems to be equally good or even better at a high number of simulations.
 
+    The exploration term is not as in original UCT but has the form
+    @f$ c * P_{move} * \sqrt{N_{parent}}/N_{child} @f$ with an exploration
+    constant c and a prior move value P (similar as used in AlphaGo
+    @ref libboardgame_doc_alphago_2016).
+
     @tparam S The game-dependent state of a simulation. The state provides
     functions for move generation, evaluation of terminal positions, etc. The
     state should be thread-safe to support multiple states if multi-threading
@@ -162,21 +171,22 @@ template<class S, class M, class R = SearchParamConstDefault>
 class SearchBase
 {
 public:
-    typedef S State;
+    using State = S;
 
-    typedef M Move;
+    using Move = M;
 
-    typedef R SearchParamConst;
+    using SearchParamConst = R;
 
     static const bool multithread = SearchParamConst::multithread;
 
-    typedef typename SearchParamConst::Float Float;
+    using Float = typename SearchParamConst::Float;
 
-    typedef libboardgame_mcts::Node<M, Float, multithread> Node;
+    using Node = libboardgame_mcts::Node<M, Float, multithread>;
 
-    typedef libboardgame_mcts::Tree<Node> Tree;
+    using Tree = libboardgame_mcts::Tree<Node>;
+
+    using PlayerMove = libboardgame_mcts::PlayerMove<M>;
 
-    typedef libboardgame_mcts::PlayerMove<M> PlayerMove;
 
     static const PlayerInt max_players = SearchParamConst::max_players;
 
@@ -264,7 +274,7 @@ public:
     Float get_rave_parent_max() const;
 
     /** Maximum child value count for applying RAVE. */
-    void set_rave_child_max(Float value);
+    void set_rave_child_max(Float n);
 
     Float get_rave_child_max() const;
 
@@ -316,7 +326,7 @@ public:
         estimated time left.
         The callback function will be called about every 0.1s. The arguments
         of the callback function are: elapsed time, estimated remaining time. */
-    void set_callback(function<void(double, double)> callback);
+    void set_callback(const function<void(double, double)>& callback);
 
     /** Get evaluation for a player at root node. */
     const StatisticsDirtyLockFree<Float>& get_root_val(PlayerInt player) const;
@@ -350,10 +360,6 @@ protected:
 
     virtual void on_start_search(bool is_followup);
 
-    /** Time source for current search.
-        Only valid during a search. */
-    TimeSource& get_time_source();
-
 private:
 #if LIBBOARDGAME_DEBUG
     class AssertionHandler
@@ -362,8 +368,6 @@ private:
     public:
         explicit AssertionHandler(const SearchBase& search);
 
-        ~AssertionHandler();
-
         void run() override;
 
     private:
@@ -395,8 +399,6 @@ private:
         /** Local variable for update_rave().
             Reused for efficiency. */
         array<unsigned, Move::range> first_play;
-
-        ~ThreadState();
     };
 
     /** Thread in the parallel search.
@@ -407,7 +409,8 @@ private:
     class Thread
     {
     public:
-        typedef function<void(ThreadState&)> SearchFunc;
+        using SearchFunc = function<void(ThreadState&)>;
+
 
         ThreadState thread_state;
 
@@ -554,9 +557,6 @@ private:
 };
 
 
-template<class S, class M, class R>
-SearchBase<S, M, R>::ThreadState::~ThreadState() = default;
-
 template<class S, class M, class R>
 SearchBase<S, M, R>::Thread::Thread(SearchFunc& search_func)
     : m_search_func(search_func)
@@ -635,9 +635,6 @@ SearchBase<S, M, R>::AssertionHandler::AssertionHandler(
 {
 }
 
-template<class S, class M, class R>
-SearchBase<S, M, R>::AssertionHandler::~AssertionHandler() = default;
-
 template<class S, class M, class R>
 void SearchBase<S, M, R>::AssertionHandler::run()
 {
@@ -658,7 +655,7 @@ SearchBase<S, M, R>::SearchBase(unsigned nu_threads, size_t memory)
 { }
 
 template<class S, class M, class R>
-SearchBase<S, M, R>::~SearchBase() = default;
+SearchBase<S, M, R>::~SearchBase() = default; // Non-inline to avoid GCC -Winline warning
 
 template<class S, class M, class R>
 bool SearchBase<S, M, R>::check_abort(const ThreadState& thread_state) const
@@ -791,7 +788,7 @@ void SearchBase<S, M, R>::create_threads()
                           bind(&SearchBase::search_loop, this, placeholders::_1));
     for (unsigned i = 0; i < m_nu_threads; ++i)
     {
-        unique_ptr<Thread> t(new Thread(search_func));
+        auto t = make_unique<Thread>(search_func);
         auto& thread_state = t->thread_state;
         thread_state.thread_id = i;
         thread_state.state = create_state();
@@ -825,7 +822,8 @@ bool SearchBase<S, M, R>::expand_node(ThreadState& thread_state,
     auto& state = *thread_state.state;
     auto thread_id = thread_state.thread_id;
     typename Tree::NodeExpander expander(thread_id, m_tree,
-                                         SearchParamConst::child_min_count);
+                                         SearchParamConst::child_min_count,
+                                         SearchParamConst::max_move_prior);
     auto root_val = m_root_val[state.get_player()].get_mean();
     if (state.gen_children(expander, root_val))
     {
@@ -907,13 +905,6 @@ inline const S& SearchBase<S, M, R>::get_state(unsigned thread_id) const
     return *m_threads[thread_id]->thread_state.state;
 }
 
-template<class S, class M, class R>
-inline TimeSource& SearchBase<S, M, R>::get_time_source()
-{
-    LIBBOARDGAME_ASSERT(m_time_source != 0);
-    return *m_time_source;
-}
-
 template<class S, class M, class R>
 inline auto SearchBase<S, M, R>::get_tree() const -> const Tree&
 {
@@ -956,7 +947,7 @@ void SearchBase<S, M, R>::play_in_tree(ThreadState& thread_state)
     simulation.moves.clear();
     auto& root = m_tree.get_root();
     auto node = &root;
-    Float expand_threshold = SearchParamConst::expand_threshold;
+    Float expansion_threshold = SearchParamConst::expansion_threshold;
     while (node->has_children())
     {
         node = select_child(*node);
@@ -966,10 +957,10 @@ void SearchBase<S, M, R>::play_in_tree(ThreadState& thread_state)
         Move mv = node->get_move();
         simulation.moves.push_back(PlayerMove(state.get_player(), mv));
         state.play_in_tree(mv);
-        expand_threshold += SearchParamConst::expand_threshold_inc;
+        expansion_threshold += SearchParamConst::expansion_threshold_inc;
     }
     state.finish_in_tree();
-    if (node->get_visit_count() > expand_threshold)
+    if (node->get_visit_count() > expansion_threshold)
     {
         if (! expand_node(thread_state, *node, node))
             thread_state.is_out_of_mem = true;
@@ -1029,7 +1020,7 @@ bool SearchBase<S, M, R>::prune(TimeSource& time_source, double time,
     m_tmp_tree.clear();
     m_tree.copy_subtree(m_tmp_tree, m_tmp_tree.get_root(), m_tree.get_root(),
                         prune_min_count);
-    int percent = int(m_tmp_tree.get_nu_nodes() * 100 / m_tree.get_nu_nodes());
+    auto percent = int(m_tmp_tree.get_nu_nodes() * 100 / m_tree.get_nu_nodes());
     LIBBOARDGAME_LOG("Pruning MinCnt: ", prune_min_count, ", AtTm: ", time,
                      ", Nds: ", m_tmp_tree.get_nu_nodes(), " (", percent,
                      "%), Tm: ", timer());
@@ -1041,11 +1032,8 @@ bool SearchBase<S, M, R>::prune(TimeSource& time_source, double time,
         new_prune_min_count = prune_min_count * 2;
         return true;
     }
-    else
-    {
-        new_prune_min_count = prune_min_count;
-        return true;
-    }
+    new_prune_min_count = prune_min_count;
+    return true;
 }
 
 /** Estimate the value and count of a root node from its children.
@@ -1243,7 +1231,7 @@ void SearchBase<S, M, R>::search_loop(ThreadState& thread_state)
                      ref(thread_state)));
     if (m_deterministic)
     {
-        unsigned interval =
+        auto interval =
             static_cast<unsigned>(
                     max(1.0, SearchParamConst::expected_sim_per_sec / 5.0));
         expensive_abort_checker.set_deterministic(interval);
@@ -1272,28 +1260,31 @@ void SearchBase<S, M, R>::search_loop(ThreadState& thread_state)
 template<class S, class M, class R>
 inline auto SearchBase<S, M, R>::select_child(const Node& node) -> const Node*
 {
-    auto children = m_tree.get_children(node);
-    LIBBOARDGAME_ASSERT(! children.empty());
     auto parent_count = node.get_visit_count();
     Float bias_factor = m_exploration_constant * sqrt(parent_count);
     static_assert(SearchParamConst::child_min_count > 0, "");
-    auto bias_limit = bias_factor / SearchParamConst::child_min_count;
+    auto bias_limit =
+            bias_factor * SearchParamConst::max_move_prior
+            / SearchParamConst::child_min_count;
+    auto children = m_tree.get_children_nonempty(node);
     auto i = children.begin();
-    auto value = i->get_value() + bias_factor / i->get_value_count();
+    auto value =
+            i->get_value()
+            + i->get_move_prior() * bias_factor / i->get_value_count();
     auto best_value = value;
-    auto best_child = i;
     auto limit = best_value - bias_limit;
+    auto best_child = i;
     while (++i != children.end())
     {
         value = i->get_value();
         if (value <= limit)
             continue;
-        value += bias_factor / i->get_value_count();
+        value += i->get_move_prior() * bias_factor / i->get_value_count();
         if (value > best_value)
         {
             best_value = value;
-            best_child = i;
             limit = best_value - bias_limit;
+            best_child = i;
         }
     }
     return best_child;
@@ -1303,7 +1294,7 @@ template<class S, class M, class R>
 auto SearchBase<S, M, R>::select_final() const-> const Node*
 {
     // Select the child with the highest number of wins
-    auto children = m_tree.get_children(m_tree.get_root());
+    auto children = m_tree.get_children_nonempty(m_tree.get_root());
     if (children.empty())
         return nullptr;
     auto i = children.begin();
@@ -1330,12 +1321,12 @@ bool SearchBase<S, M, R>::select_move(Move& mv) const
         mv = child->get_move();
         return true;
     }
-    else
-        return false;
+    return false;
 }
 
 template<class S, class M, class R>
-void SearchBase<S, M, R>::set_callback(function<void(double, double)> callback)
+void SearchBase<S, M, R>::set_callback(
+        const function<void(double, double)>& callback)
 {
     m_callback = callback;
 }
@@ -1415,7 +1406,7 @@ void SearchBase<S, M, R>::update_rave(ThreadState& thread_state)
     auto& was_played = thread_state.was_played;
     auto& first_play = thread_state.first_play;
     auto& nodes = thread_state.simulation.nodes;
-    unsigned nu_nodes = static_cast<unsigned>(nodes.size());
+    auto nu_nodes = static_cast<unsigned>(nodes.size());
     unsigned i = nu_moves - 1;
     // nu_nodes is at least 2 (including root) because the case of no legal
     // moves at the root is already handled before running any simulations.
@@ -1442,7 +1433,7 @@ void SearchBase<S, M, R>::update_rave(ThreadState& thread_state)
         Float dist_factor;
         if (SearchParamConst::rave_dist_weighting)
             dist_factor = 1 / static_cast<Float>(nu_moves - i);
-        auto children = m_tree.get_children(*node);
+        auto children = m_tree.get_children_nonempty(*node);
         LIBBOARDGAME_ASSERT(! children.empty());
         auto it = children.begin();
         do
@@ -1480,7 +1471,7 @@ void SearchBase<S, M, R>::update_values(ThreadState& thread_state)
     const auto& simulation = thread_state.simulation;
     auto& nodes = simulation.nodes;
     auto& eval = simulation.eval;
-    unsigned nu_nodes = static_cast<unsigned>(nodes.size());
+    auto nu_nodes = static_cast<unsigned>(nodes.size());
     m_tree.inc_visit_count(*nodes[0]);
     for (unsigned i = 1; i < nu_nodes; ++i)
     {
