@@ -14,6 +14,7 @@
 namespace libboardgame_mcts {
 
 using namespace std;
+using libboardgame_util::Range;
 
 //-----------------------------------------------------------------------------
 
@@ -33,44 +34,14 @@ class Tree
     friend class NodeExpander;
 
 public:
-    typedef N Node;
+    using Node = N;
 
-    typedef typename Node::Move Move;
+    using Move = typename Node::Move;
 
-    typedef typename Node::Float Float;
+    using Float = typename Node::Float;
 
     /** Range for iterating over the children of a node. */
-    class Children
-    {
-    public:
-        Children(const Tree& tree, const Node& node)
-        {
-            auto nu_children = node.get_nu_children();
-            m_begin = (nu_children != 0 ?
-                        &tree.get_node(node.get_first_child()) : nullptr);
-            m_end = m_begin + nu_children;
-        }
-
-        const Node* begin() const
-        {
-            return m_begin;
-        }
-
-        const Node* end() const
-        {
-            return m_end;
-        }
-
-        bool empty() const
-        {
-            return m_begin == nullptr;
-        }
-
-    private:
-        const Node* m_begin;
-
-        const Node* m_end;
-    };
+    using Children = Range<const Node>;
 
 
     /** Helper class that is passed to the search state during node expansion.
@@ -85,10 +56,13 @@ public:
             @param thread_id
             @param tree
             @param child_min_count The minimum count used for initializing
-            children. Used only in debug mode to assert that the children
-            are really initialized with a minimum count as declared with
-            SearchParamConst::child_min_count. */
-        NodeExpander(unsigned thread_id, Tree& tree, Float child_min_count);
+            children. Used only in debug mode to verify the arguments for
+            add_child().
+            @param max_move_prior The maximum move prior used for initializing
+            children. Used only in debug mode to verify the arguments for
+            add_child(). */
+        NodeExpander(unsigned thread_id, Tree& tree, Float child_min_count,
+                     Float max_move_prior);
 
         /** Check if the tree still has the capacity for a given number
             of children. */
@@ -97,7 +71,8 @@ public:
         /** Add new child.
             It needs to be checked first with check_capacity() that the tree
             has enough capacity. */
-        void add_child(const Move& mv, Float value, Float count);
+        void add_child(const Move& mv, Float value, Float count,
+                       Float move_prior);
 
         /** Link the children to the parent node. */
         void link_children(Tree& tree, const Node& node);
@@ -112,7 +87,7 @@ public:
     private:
         ThreadStorage& m_thread_storage;
 
-        Float m_best_value = -numeric_limits<Float>::max();
+        Float m_best_move_prior = -numeric_limits<Float>::max();
 
         const Node* m_first_child;
 
@@ -120,27 +95,24 @@ public:
 
 #if LIBBOARDGAME_DEBUG
         Float m_child_min_count;
+
+        Float m_max_move_prior;
 #endif
     };
 
     Tree(size_t memory, unsigned nu_threads);
 
-    ~Tree();
 
     /** Remove all nodes but the root node. */
     void clear();
 
     const Node& get_root() const;
 
-    Children get_children(const Node& node) const
-    {
-        return Children(*this, node);
-    }
+    Children get_children(const Node& node) const;
 
-    Children get_root_children() const
-    {
-        return get_children(get_root());
-    }
+    Children get_children_nonempty(const Node& node) const;
+
+    Children get_root_children() const { return get_children(get_root()); }
 
     size_t get_nu_nodes() const;
 
@@ -212,7 +184,8 @@ private:
 
 template<typename N>
 inline Tree<N>::NodeExpander::NodeExpander(unsigned thread_id, Tree& tree,
-                                           Float child_min_count)
+                                           Float child_min_count,
+                                           Float max_move_prior)
     : m_thread_storage(tree.m_thread_storage[thread_id]),
       m_first_child(m_thread_storage.next),
       m_best_child(nullptr)
@@ -220,25 +193,28 @@ inline Tree<N>::NodeExpander::NodeExpander(unsigned thread_id, Tree& tree,
     LIBBOARDGAME_ASSERT(thread_id < tree.m_nu_threads);
 #if LIBBOARDGAME_DEBUG
     m_child_min_count = child_min_count;
+    m_max_move_prior = max_move_prior;
 #else
     LIBBOARDGAME_UNUSED(child_min_count);
+    LIBBOARDGAME_UNUSED(max_move_prior);
 #endif
 }
 
 template<typename N>
 inline void Tree<N>::NodeExpander::add_child(const Move& mv, Float value,
-                                             Float count)
+                                             Float count, Float move_prior)
 {
     // -numeric_limits<Float>::max() ist init value for m_best_value
     LIBBOARDGAME_ASSERT(value > -numeric_limits<Float>::max());
     LIBBOARDGAME_ASSERT(count >= m_child_min_count);
+    LIBBOARDGAME_ASSERT(move_prior <= m_max_move_prior);
     auto& next = m_thread_storage.next;
     LIBBOARDGAME_ASSERT(next < m_thread_storage.end);
-    next->init(mv, value, count);
-    if (value > m_best_value)
+    next->init(mv, value, count, move_prior);
+    if (move_prior > m_best_move_prior)
     {
         m_best_child = next;
-        m_best_value = value;
+        m_best_move_prior = move_prior;
     }
     ++next;
 }
@@ -256,6 +232,23 @@ inline auto Tree<N>::NodeExpander::get_best_child() const -> const Node*
     return m_best_child;
 }
 
+template<typename N>
+inline auto Tree<N>::get_children(const Node& node) const -> Children
+{
+    auto nu_children = node.get_nu_children();
+    auto begin = nu_children != 0 ? &get_node(node.get_first_child()) : nullptr;
+    auto end = begin + nu_children;
+    return Children(begin, end);
+}
+
+template<typename N>
+inline auto Tree<N>::get_children_nonempty(const Node& node) const -> Children
+{
+    auto begin = &get_node(node.get_first_child());
+    auto end = begin + node.get_nu_children();
+    return Children(begin, end);
+}
+
 template<typename N>
 inline auto Tree<N>::get_node(NodeIdx i) const -> const Node&
 {
@@ -285,8 +278,8 @@ Tree<N>::Tree(size_t memory, unsigned nu_threads)
         min(max_nodes, static_cast<size_t>(numeric_limits<NodeIdx>::max()));
     m_nu_threads = nu_threads;
     m_max_nodes = max_nodes;
-    m_nodes.reset(new Node[max_nodes]);
-    m_thread_storage.reset(new ThreadStorage[nu_threads]);
+    m_nodes = make_unique<Node[]>(max_nodes);
+    m_thread_storage = make_unique<ThreadStorage[]>(nu_threads);
     m_nodes_per_thread = max_nodes / nu_threads;
     for (unsigned i = 0; i < nu_threads; ++i)
     {
@@ -297,9 +290,6 @@ Tree<N>::Tree(size_t memory, unsigned nu_threads)
     clear();
 }
 
-template<typename N>
-Tree<N>::~Tree() = default;
-
 template<typename N>
 inline void Tree<N>::add_value(const Node& node, Float v)
 {
@@ -420,7 +410,7 @@ template<typename N>
 inline void Tree<N>::link_children(const Node& node, const Node* first_child,
                                    unsigned short nu_children)
 {
-    NodeIdx first_child_idx = static_cast<NodeIdx>(first_child - m_nodes.get());
+    auto first_child_idx = static_cast<NodeIdx>(first_child - m_nodes.get());
     LIBBOARDGAME_ASSERT(first_child_idx > 0);
     LIBBOARDGAME_ASSERT(first_child_idx < m_max_nodes);
     non_const(node).link_children(first_child_idx, nu_children);
