@@ -14,9 +14,9 @@ namespace libboardgame_sgf {
 
 //-----------------------------------------------------------------------------
 
-TreeReader::TreeReader() = default;
+TreeReader::TreeReader() = default; // Non-inline to avoid GCC -Winline warning
 
-TreeReader::~TreeReader() = default;
+TreeReader::~TreeReader() = default; // Non-inline to avoid GCC -Winline warning
 
 unique_ptr<SgfNode> TreeReader::get_tree_transfer_ownership()
 {
@@ -43,7 +43,7 @@ void TreeReader::on_begin_node(bool is_root)
 {
     if (is_root)
     {
-        m_root.reset(new SgfNode);
+        m_root = make_unique<SgfNode>();
         m_current = m_root.get();
     }
     else
