@@ -18,9 +18,9 @@ Options::Options(int argc, const char** argv, const vector<string>& specs)
 {
     for (auto& s : specs)
     {
-        auto pos = s.find("|");
+        auto pos = s.find('|');
         if (pos == string::npos)
-            pos = s.find(":");
+            pos = s.find(':');
         if (pos != string::npos)
             m_names.insert(s.substr(0, pos));
         else
@@ -62,7 +62,7 @@ Options::Options(int argc, const char** argv, const vector<string>& specs)
             else
             {
                 // Short options
-                for (unsigned i = 1; i < arg.size(); ++i)
+                for (string::size_type i = 1; i < arg.size(); ++i)
                 {
                     auto c = arg[i];
                     bool found = false;
@@ -117,7 +117,7 @@ Options::Options(int argc, char** argv, const vector<string>& specs)
 {
 }
 
-Options::~Options() = default;
+Options::~Options() = default; // Non-inline to avoid GCC -Winline warning
 
 void Options::check_name(const string& name) const
 {
