@@ -11,6 +11,7 @@
 #include "StringUtil.h"
 
 #include <cctype>
+#include <cmath>
 #include <iomanip>
 
 namespace libboardgame_util {
@@ -59,7 +60,7 @@ vector<string> split(const string& s, char separator)
 
 string time_to_string(double seconds, bool with_seconds_as_double)
 {
-    int int_seconds = int(seconds + 0.5);
+    auto int_seconds = static_cast<int>(round(seconds));
     int hours = int_seconds / 3600;
     int_seconds -= hours * 3600;
     int minutes = int_seconds / 60;
@@ -85,9 +86,9 @@ string trim(const string& s)
 {
     string::size_type begin = 0;
     auto end = s.size();
-    while (begin != end && isspace(s[begin]))
+    while (begin != end && isspace(s[begin]) != 0)
         ++begin;
-    while (end > begin && isspace(s[end - 1]))
+    while (end > begin && isspace(s[end - 1]) != 0)
         --end;
     return s.substr(begin, end - begin);
 }
@@ -95,7 +96,7 @@ string trim(const string& s)
 string trim_right(const string& s)
 {
     auto end = s.size();
-    while (end > 0 && isspace(s[end - 1]))
+    while (end > 0 && isspace(s[end - 1]) != 0)
         --end;
     return s.substr(0, end);
 }
