@@ -7,7 +7,6 @@
 #ifndef LIBBOARDGAME_UTIL_WALL_TIME_SOURCE_H
 #define LIBBOARDGAME_UTIL_WALL_TIME_SOURCE_H
 
-#include <chrono>
 #include "TimeSource.h"
 
 namespace libboardgame_util {
@@ -20,12 +19,7 @@ class WallTimeSource
     : public TimeSource
 {
 public:
-    WallTimeSource();
-
     double operator()() override;
-
-private:
-    std::chrono::system_clock::time_point m_start;
 };
 //-----------------------------------------------------------------------------
 
