@@ -157,7 +157,7 @@ void Board::gen_moves(Color c, Point p, Piece piece, unsigned adj_status,
 
 ScoreType Board::get_bonus(Color c) const
 {
-    if (get_pieces_left(c).size() > 0)
+    if (! get_pieces_left(c).empty())
         return 0;
     auto bonus = m_bonus_all_pieces;
     unsigned i = m_moves.size();
@@ -204,8 +204,7 @@ void Board::get_place(Color c, unsigned& place, bool& is_shared) const
             all_scores[i] += i * 0.0001f;
     }
     auto score = all_scores[c.to_int()];
-    sort(all_scores.begin(), all_scores.begin() + m_nu_players,
-         greater<ScoreType>());
+    sort(all_scores.begin(), all_scores.begin() + m_nu_players, greater<>());
     is_shared = false;
     bool found = false;
     for (unsigned i = 0; i < m_nu_players; ++i)
@@ -313,7 +312,7 @@ void Board::init(Variant variant, const Setup* setup)
         m_attach_points[c].clear();
     }
     m_state_base.nu_onboard_pieces_all = 0;
-    if (! setup)
+    if (setup == nullptr)
     {
         m_setup.clear();
         m_state_base.to_play = Color(0);
@@ -335,7 +334,25 @@ void Board::init_variant(Variant variant)
 {
     m_variant = variant;
     m_nu_colors = libpentobi_base::get_nu_colors(variant);
-    if (m_nu_colors == 2)
+    if (variant == Variant::duo)
+    {
+        m_color_name[Color(0)] = "Purple";
+        m_color_name[Color(1)] = "Orange";
+        m_color_esc_sequence[Color(0)] = "\x1B[1;35;47m";
+        m_color_esc_sequence[Color(1)] = "\x1B[1;33;47m";
+        m_color_esc_sequence_text[Color(0)] = "\x1B[1;35m";
+        m_color_esc_sequence_text[Color(1)] = "\x1B[1;33m";
+    }
+    else if (variant == Variant::junior)
+    {
+        m_color_name[Color(0)] = "Green";
+        m_color_name[Color(1)] = "Orange";
+        m_color_esc_sequence[Color(0)] = "\x1B[1;32;47m";
+        m_color_esc_sequence[Color(1)] = "\x1B[1;33;47m";
+        m_color_esc_sequence_text[Color(0)] = "\x1B[1;32m";
+        m_color_esc_sequence_text[Color(1)] = "\x1B[1;33m";
+    }
+    else if (m_nu_colors == 2)
     {
         m_color_name[Color(0)] = "Blue";
         m_color_name[Color(1)] = "Green";
@@ -436,7 +453,7 @@ bool Board::is_legal(Color c, Move mv) const
     {
         if (m_state_color[c].forbidden[*i])
             return false;
-        has_attach_point |= is_attach_point(*i, c);
+        has_attach_point |= static_cast<int>(is_attach_point(*i, c));
     }
     while (++i != end);
     if (m_is_callisto)
@@ -561,18 +578,18 @@ void Board::write(ostream& out, bool mark_last_move) const
         if (n > 0)
             last_mv = get_move(n - 1);
     }
-    unsigned width = m_geo->get_width();
-    unsigned height = m_geo->get_height();
+    int width = m_geo->get_width();
+    int height = m_geo->get_height();
     bool is_info_location_right = (width <= 20);
     bool is_trigon = (m_piece_set == PieceSet::trigon);
     bool is_nexos = (m_piece_set == PieceSet::nexos);
     bool is_gembloq = (m_piece_set == PieceSet::gembloq);
-    for (unsigned y = 0; y < height; ++y)
+    for (int y = 0; y < height; ++y)
     {
         if (height - y < 10)
             out << ' ';
         out << (height - y) << ' ';
-        for (unsigned x = 0; x < width; ++x)
+        for (int x = 0; x < width; ++x)
         {
             Point p = m_geo->get_point(x, y);
             bool is_offboard = p.is_null();
@@ -587,7 +604,7 @@ void Board::write(ostream& out, bool mark_last_move) const
                 // space to mark the last piece played.
                 if (! last_mv.is_null()
                         && get_move_points(last_mv.move).contains(p)
-                        && (x == 0 || ! m_geo->is_onboard(x - 1, y)
+                        && (! m_geo->is_onboard(x - 1, y)
                             || get_point_state(m_geo->get_point(x - 1, y))
                                != last_mv.color))
                 {
@@ -596,7 +613,7 @@ void Board::write(ostream& out, bool mark_last_move) const
                     last_mv = ColorMove::null();
                 }
                 else if (! last_mv.is_null()
-                         && x > 0 && m_geo->is_onboard(x - 1, y)
+                         && m_geo->is_onboard(x - 1, y)
                          && get_move_points(last_mv.move).contains(
                                                    m_geo->get_point(x - 1, y))
                          && get_point_state(p) != last_mv.color
@@ -628,12 +645,12 @@ void Board::write(ostream& out, bool mark_last_move) const
             }
             if (is_offboard)
             {
-                if (is_trigon && x > 0 && m_geo->is_onboard(x - 1, y))
+                if (is_trigon && m_geo->is_onboard(x - 1, y))
                 {
                     set_color(out, "\x1B[1;30;47m");
                     out << (point_type == 1 ? '\\' : '/');
                 }
-                else if (is_gembloq && x > 0 && m_geo->is_onboard(x - 1, y))
+                else if (is_gembloq && m_geo->is_onboard(x - 1, y))
                 {
                     set_color(out, "\x1B[1;30;47m");
                     if (point_type == 1)
