@@ -30,17 +30,17 @@ class MoveMarker;
 class Board
 {
 public:
-    typedef Grid<PointState> PointStateGrid;
+    using PointStateGrid = Grid<PointState>;
 
     /** Maximum number of pieces per player in any game variant. */
     static const unsigned max_pieces = Setup::max_pieces;
 
-    typedef ArrayList<Piece, Piece::max_pieces> PiecesLeftList;
+    using PiecesLeftList = ArrayList<Piece, Piece::max_pieces>;
 
     static const unsigned max_player_moves = max_pieces;
 
     /** Maximum number of moves in any game variant. */
-    static const unsigned max_game_moves = Color::range * max_player_moves;
+    static const unsigned max_moves = Color::range * max_player_moves;
 
     /** Use ANSI escape sequences for colored text output in operator>> */
     static bool color_output;
@@ -191,7 +191,7 @@ public:
 
     ColorMove get_move(unsigned n) const;
 
-    const ArrayList<ColorMove, max_game_moves>& get_moves() const;
+    const ArrayList<ColorMove, max_moves>& get_moves() const;
 
     /** Generate all legal moves for a color.
         @param c The color
@@ -230,6 +230,8 @@ public:
 
     PieceSet get_piece_set() const { return m_piece_set; }
 
+    bool is_callisto() const { return m_is_callisto; }
+
     /** Whether ties are broken in the current game variant. */
     bool get_break_ties() const { return m_is_callisto; }
 
@@ -438,7 +440,7 @@ private:
 
     ColorMap<const char*> m_color_name;
 
-    ArrayList<ColorMove, max_game_moves> m_moves;
+    ArrayList<ColorMove, max_moves> m_moves;
 
     Snapshot m_snapshot;
 
@@ -497,11 +499,10 @@ inline Move Board::from_string(const string& s) const
 inline unsigned Board::get_adj_status(Point p, Color c) const
 {
     LIBBOARDGAME_ASSERT(m_bc->has_adj_status_points(p));
-    auto adj_status_points = m_bc->get_adj_status_points(p);
-    auto i = adj_status_points.begin();
-    unsigned result = is_forbidden(*i, c);
+    auto i = m_bc->get_adj_status_points(p).begin();
+    auto result = static_cast<unsigned>(is_forbidden(*i, c));
     for (unsigned j = 1; j < PrecompMoves::adj_status_nu_adj; ++j)
-        result |= (is_forbidden(*(++i), c) << j);
+        result |= (static_cast<unsigned>(is_forbidden(*(++i), c)) << j);
     return result;
 }
 
@@ -543,8 +544,7 @@ inline Range<const Point> Board::get_move_points(Move mv) const
     return m_bc->get_move_points(mv);
 }
 
-inline auto Board::get_moves() const
--> const ArrayList<ColorMove, max_game_moves>&
+inline auto Board::get_moves() const -> const ArrayList<ColorMove, max_moves>&
 {
     return m_moves;
 }
@@ -640,10 +640,9 @@ inline ScoreType Board::get_score(Color c) const
 {
     if (m_nu_colors == 2)
         return get_score_twocolor(c);
-    else if (m_nu_players == 2)
+    if (m_nu_players == 2)
         return get_score_multicolor(c);
-    else
-        return get_score_multiplayer(c);
+    return get_score_multiplayer(c);
 }
 
 inline ScoreType Board::get_score_twocolor(Color c) const
@@ -653,8 +652,7 @@ inline ScoreType Board::get_score_twocolor(Color c) const
     auto points1 = get_points(Color(1));
     if (c == Color(0))
         return points0 - points1;
-    else
-        return points1 - points0;
+    return points1 - points0;
 }
 
 inline ScoreType Board::get_score_twoplayer(Color c) const
@@ -662,8 +660,7 @@ inline ScoreType Board::get_score_twoplayer(Color c) const
     LIBBOARDGAME_ASSERT(m_nu_players == 2);
     if (m_nu_colors == 2)
         return get_score_twocolor(c);
-    else
-        return get_score_multicolor(c);
+    return get_score_multicolor(c);
 }
 
 inline ScoreType Board::get_score_multicolor(Color c) const
@@ -673,8 +670,7 @@ inline ScoreType Board::get_score_multicolor(Color c) const
     auto points1 = get_points(Color(1)) + get_points(Color(3));
     if (c == Color(0) || c == Color(2))
         return points0 - points1;
-    else
-        return points1 - points0;
+    return points1 - points0;
 }
 
 inline ScoreType Board::get_score_multiplayer(Color c) const
