@@ -17,15 +17,10 @@
 #include "PieceTransformsTrigon.h"
 #include "libboardgame_base/Transform.h"
 #include "libboardgame_util/Log.h"
-#include "libboardgame_util/StringUtil.h"
 #include "libboardgame_sys/Compiler.h"
 
 namespace libpentobi_base {
 
-using libboardgame_base::Transform;
-using libboardgame_util::split;
-using libboardgame_util::to_lower;
-using libboardgame_util::trim;
 using libboardgame_sys::get_type_name;
 
 //-----------------------------------------------------------------------------
@@ -59,7 +54,7 @@ bool is_reverse(MovePoints::const_iterator begin1, const Point* begin2, unsigned
 // of the y axis!)
 void sort_piece_points(PiecePoints& points)
 {
-    auto less = [](const CoordPoint& a, const CoordPoint& b)
+    auto less = [](CoordPoint a, CoordPoint b)
     {
         return ((a.y == b.y && a.x < b.x) || a.y > b.y);
     };
@@ -863,7 +858,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
     switch (piece_set)
     {
     case PieceSet::classic:
-        m_transforms.reset(new PieceTransformsClassic);
+        m_transforms = make_unique<PieceTransformsClassic>();
         m_pieces = create_pieces_classic(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 5;
         m_max_adj_attach = 16;
@@ -871,7 +866,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<16>)));
         break;
     case PieceSet::junior:
-        m_transforms.reset(new PieceTransformsClassic);
+        m_transforms = make_unique<PieceTransformsClassic>();
         m_pieces = create_pieces_junior(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 5;
         m_max_adj_attach = 16;
@@ -879,7 +874,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<16>)));
         break;
     case PieceSet::trigon:
-        m_transforms.reset(new PieceTransformsTrigon);
+        m_transforms = make_unique<PieceTransformsTrigon>();
         m_pieces = create_pieces_trigon(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 6;
         m_max_adj_attach = 22;
@@ -887,7 +882,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<22>)));
         break;
     case PieceSet::nexos:
-        m_transforms.reset(new PieceTransformsClassic);
+        m_transforms = make_unique<PieceTransformsClassic>();
         m_pieces = create_pieces_nexos(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 7;
         m_max_adj_attach = 12;
@@ -895,7 +890,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<12>)));
         break;
     case PieceSet::callisto:
-        m_transforms.reset(new PieceTransformsClassic);
+        m_transforms = make_unique<PieceTransformsClassic>();
         m_pieces = create_pieces_callisto(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 5;
         // m_max_adj_attach is actually 10 in Callisto, but we care more about
@@ -907,7 +902,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<16>)));
         break;
     case PieceSet::gembloq:
-        m_transforms.reset(new PieceTransformsGembloQ);
+        m_transforms = make_unique<PieceTransformsGembloQ>();
         m_pieces = create_pieces_gembloq(m_geo, piece_set, *m_transforms);
         m_max_piece_size = 22;
         m_max_adj_attach = 44;
@@ -915,7 +910,7 @@ BoardConst::BoardConst(BoardType board_type, PieceSet piece_set)
         m_move_info_ext.reset(calloc(m_range, sizeof(MoveInfoExt<44>)));
         break;
     }
-    m_move_info_ext_2.reset(new MoveInfoExt2[m_range]);
+    m_move_info_ext_2 = make_unique<MoveInfoExt2[]>(m_range);
     m_nu_pieces = static_cast<Piece::IntType>(m_pieces.size());
     for (Point p : m_geo)
         if (has_adj_status_points(p))
@@ -1117,7 +1112,7 @@ void BoardConst::create_moves(unsigned& moves_created, Piece piece)
                 auto& pp = transformed_points[i][j];
                 int xx = pp.x + x;
                 int yy = pp.y + y;
-                if (! m_geo.is_onboard(CoordPoint(xx, yy)))
+                if (! m_geo.is_onboard(xx, yy))
                 {
                     is_onboard = false;
                     break;
@@ -1138,19 +1133,23 @@ void BoardConst::create_moves(unsigned& moves_created, Piece piece)
 
 Move BoardConst::from_string(const string& s) const
 {
-    string trimmed = to_lower(trim(s));
-    if (trimmed == "null")
-        return Move::null();
-    vector<string> v = split(trimmed, ',');
-    if (v.size() > PieceInfo::max_size)
-        throw runtime_error("illegal move (too many points)");
     MovePoints points;
-    for (const auto& s : v)
+    auto begin = s.begin();
+    auto end = begin;
+    while (true)
     {
+        while (end != s.end() && *end != ',')
+            ++end;
         Point p;
-        if (! m_geo.from_string(s, p))
+        if (! m_geo.from_string(begin, end, p))
             throw runtime_error("illegal move (invalid point)");
+        if (points.size() == points.max_size)
+            throw runtime_error("illegal move (too many points)");
         points.push_back(p);
+        if (end == s.end())
+            break;
+        ++end;
+        begin = end;
     }
     Move mv;
     if (! find_move(points, mv))
@@ -1182,6 +1181,8 @@ bool BoardConst::get_piece_by_name(const string& name, Piece& piece) const
 
 bool BoardConst::find_move(const MovePoints& points, Move& move) const
 {
+    if (points.empty())
+        return false;
     MovePoints sorted_points = points;
     sort(sorted_points);
     for (Piece::IntType i = 0; i < m_pieces.size(); ++i)
