@@ -14,13 +14,11 @@
 #include "PrecompMoves.h"
 #include "SymmetricPoints.h"
 #include "Variant.h"
-#include "libboardgame_util/ArrayList.h"
 #include "libboardgame_util/Range.h"
 
 namespace libpentobi_base {
 
 using namespace std;
-using libboardgame_util::ArrayList;
 using libboardgame_util::Range;
 
 //-----------------------------------------------------------------------------
@@ -31,17 +29,18 @@ class BoardConst
 {
 public:
     /** See get_adj_status_points() */
-    typedef array<Point, PrecompMoves::adj_status_nu_adj> AdjStatusPoints;
+    using AdjStatusPoints = array<Point, PrecompMoves::adj_status_nu_adj>;
 
     /** Start of the MoveInfo array, which can be cached by the user in
         performance-critical code and then passed into the static version of
         get_move_info(). */
-    typedef const void* MoveInfoArray;
+    using MoveInfoArray = const void*;
 
     /** Start of the MoveInfoExt array, which can be cached by the user in
         performance-critical code and then passed into the static version of
         get_move_info_ext(). */
-    typedef const void* MoveInfoExtArray;
+    using MoveInfoExtArray = const void*;
+
 
     /** Get the single instance for a given board size.
         The instance is created the first time this function is called.
@@ -123,7 +122,7 @@ public:
     /** Array containing the points used for the adjacent status.
         Contains a selection of first-order or second-order adjacent and
         diagonal neighbor points.
-        @requires has_adj_status_points(p) */
+        @pre has_adj_status_points(p) */
     const AdjStatusPoints& get_adj_status_points(Point p) const
     {
         return m_adj_status_points[p];
@@ -286,15 +285,12 @@ inline Piece BoardConst::get_move_piece(Move mv) const
 {
     if (m_max_piece_size == 5)
         return get_move_piece<5>(mv);
-    else if (m_max_piece_size == 6)
+    if (m_max_piece_size == 6)
         return get_move_piece<6>(mv);
-    else if (m_max_piece_size == 7)
+    if (m_max_piece_size == 7)
         return get_move_piece<7>(mv);
-    else
-    {
-        LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
-        return get_move_piece<22>(mv);
-    }
+    LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
+    return get_move_piece<22>(mv);
 }
 
 inline Range<const Point> BoardConst::get_move_points(Move mv) const
@@ -304,37 +300,31 @@ inline Range<const Point> BoardConst::get_move_points(Move mv) const
         auto& info = get_move_info<5>(mv);
         return Range<const Point>(info.begin(), info.end());
     }
-    else if (m_max_piece_size == 6)
+    if (m_max_piece_size == 6)
     {
         auto& info = get_move_info<6>(mv);
         return Range<const Point>(info.begin(), info.end());
     }
-    else if (m_max_piece_size == 7)
+    if (m_max_piece_size == 7)
     {
         auto& info = get_move_info<7>(mv);
         return Range<const Point>(info.begin(), info.end());
     }
-    else
-    {
-        LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
-        auto& info = get_move_info<22>(mv);
-        return Range<const Point>(info.begin(), info.end());
-    }
+    LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
+    auto& info = get_move_info<22>(mv);
+    return Range<const Point>(info.begin(), info.end());
 }
 
 inline const Point* BoardConst::get_move_points_begin(Move mv) const
 {
     if (m_max_piece_size == 5)
         return get_move_points_begin<5>(mv);
-    else if (m_max_piece_size == 6)
+    if (m_max_piece_size == 6)
         return get_move_points_begin<6>(mv);
-    else if (m_max_piece_size == 7)
+    if (m_max_piece_size == 7)
         return get_move_points_begin<7>(mv);
-    else
-    {
-        LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
-        return get_move_points_begin<22>(mv);
-    }
+    LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
+    return get_move_points_begin<22>(mv);
 }
 
 template<unsigned MAX_SIZE>
