@@ -18,20 +18,6 @@
 
 namespace libpentobi_base {
 
-using libboardgame_base::PointTransfIdent;
-using libboardgame_base::PointTransfRefl;
-using libboardgame_base::PointTransfReflRot180;
-using libboardgame_base::PointTransfRot180;
-using libboardgame_base::PointTransfRot270Refl;
-using libboardgame_base::PointTransfTrigonReflRot60;
-using libboardgame_base::PointTransfTrigonReflRot120;
-using libboardgame_base::PointTransfTrigonReflRot240;
-using libboardgame_base::PointTransfTrigonReflRot300;
-using libboardgame_base::PointTransfTrigonRot60;
-using libboardgame_base::PointTransfTrigonRot120;
-using libboardgame_base::PointTransfTrigonRot240;
-using libboardgame_base::PointTransfTrigonRot300;
-using libboardgame_sgf::InvalidPropertyValue;
 using libboardgame_sgf::TreeReader;
 using boardutil::get_transformed;
 
@@ -43,7 +29,7 @@ Book::Book(Variant variant)
     get_transforms(variant, m_transforms, m_inv_transforms);
 }
 
-Book::~Book() = default;
+Book::~Book() = default; // Non-inline to avoid GCC -Winline warning
 
 Move Book::genmove(const Board& bd, Color c)
 {
@@ -68,11 +54,11 @@ bool Book::genmove(const Board& bd, Color c, Move& mv,
         ColorMove color_mv = bd.get_move(i);
         color_mv.move = get_transformed(bd, color_mv.move, transform);
         node = m_tree.find_child_with_move(*node, color_mv);
-        if (! node)
+        if (node == nullptr)
             return false;
     }
     node = select_child(bd, c, m_tree, *node, inv_transform);
-    if (! node)
+    if (node == nullptr)
         return false;
     mv = get_transformed(bd, m_tree.get_move(*node).move, inv_transform);
     return true;
@@ -133,7 +119,7 @@ const SgfNode* Book::select_child(const Board& bd, Color c,
     if (good_moves.empty())
         return nullptr;
     LIBBOARDGAME_LOG("Book moves: ", good_moves.size());
-    unsigned nu_good_moves = static_cast<unsigned>(good_moves.size());
+    auto nu_good_moves = static_cast<unsigned>(good_moves.size());
     return good_moves[m_random.generate() % nu_good_moves];
 }
 
