@@ -11,15 +11,12 @@
 #include "Color.h"
 
 #include <sstream>
-#include "libboardgame_util/StringUtil.h"
 
 namespace libpentobi_base {
 
-using libboardgame_util::to_lower;
-
 //-----------------------------------------------------------------------------
 
-ostream& operator<<(ostream& out, const Color& c)
+ostream& operator<<(ostream& out, Color c)
 {
     out << (c.to_int() + 1);
     return out;
