@@ -21,10 +21,8 @@
 namespace libpentobi_base {
 
 using libboardgame_gtp::Failure;
-using libboardgame_sgf::InvalidPropertyValue;
 using libboardgame_sgf::TreeReader;
 using libboardgame_sgf::util::get_last_node;
-using libboardgame_util::ArrayList;
 using libboardgame_util::RandomGenerator;
 
 //-----------------------------------------------------------------------------
@@ -54,11 +52,11 @@ void Engine::board_changed()
         LIBBOARDGAME_LOG(get_board());
 }
 
-void Engine::cmd_all_legal(const Arguments& args, Response& response)
+void Engine::cmd_all_legal(Arguments args, Response& response)
 {
     auto& bd = get_board();
-    unique_ptr<MoveList> moves(new MoveList);
-    unique_ptr<MoveMarker> marker(new MoveMarker);
+    auto moves = make_unique<MoveList>();
+    auto marker = make_unique<MoveMarker>();
     bd.gen_moves(get_color_arg(args), *marker, *moves);
     for (Move mv : *moves)
         response << bd.to_string(mv, false) << '\n';
@@ -95,12 +93,12 @@ void Engine::cmd_g(Response& response)
     genmove(get_board().get_effective_to_play(), response);
 }
 
-void Engine::cmd_genmove(const Arguments& args, Response& response)
+void Engine::cmd_genmove(Arguments args, Response& response)
 {
     genmove(get_color_arg(args), response);
 }
 
-void Engine::cmd_get_place(const Arguments& args, Response& response)
+void Engine::cmd_get_place(Arguments args, Response& response)
 {
     auto& bd = get_board();
     unsigned place;
@@ -111,7 +109,7 @@ void Engine::cmd_get_place(const Arguments& args, Response& response)
         response << " shared";
 }
 
-void Engine::cmd_loadsgf(const Arguments& args)
+void Engine::cmd_loadsgf(Arguments args)
 {
     args.check_size_less_equal(2);
     string file = args.get(0);
@@ -127,7 +125,7 @@ void Engine::cmd_loadsgf(const Arguments& args)
         const SgfNode* node = nullptr;
         if (move_number != -1)
             node = m_game.get_tree().get_node_before_move_number(move_number);
-        if (! node)
+        if (node == nullptr)
             node = &get_last_node(m_game.get_root());
         m_game.goto_node(*node);
         board_changed();
@@ -139,7 +137,7 @@ void Engine::cmd_loadsgf(const Arguments& args)
 }
 
 /** Return move info of a move given by its integer or string representation. */
-void Engine::cmd_move_info(const Arguments& args, Response& response)
+void Engine::cmd_move_info(Arguments args, Response& response)
 {
     auto& bd = get_board();
     Move mv;
@@ -178,12 +176,12 @@ void Engine::cmd_move_info(const Arguments& args, Response& response)
         << "SymMv:  " << bd.to_string(info_ext_2.symmetric_move);
 }
 
-void Engine::cmd_p(const Arguments& args)
+void Engine::cmd_p(Arguments args)
 {
     play(get_board().get_to_play(), args, 0);
 }
 
-void Engine::cmd_param_base(const Arguments& args, Response& response)
+void Engine::cmd_param_base(Arguments args, Response& response)
 {
     if (args.get_size() == 0)
         response
@@ -206,7 +204,7 @@ void Engine::cmd_param_base(const Arguments& args, Response& response)
     }
 }
 
-void Engine::cmd_play(const Arguments& args)
+void Engine::cmd_play(Arguments args)
 {
     play(get_color_arg(args, 0), args, 1);
 }
@@ -220,7 +218,7 @@ void Engine::cmd_point_integers(Response& response)
     response << '\n' << grid.to_string(geo);
 }
 
-void Engine::cmd_reg_genmove(const Arguments& args, Response& response)
+void Engine::cmd_reg_genmove(Arguments args, Response& response)
 {
     RandomGenerator::set_global_seed_last();
     Move move = get_player().genmove(get_board(), get_color_arg(args));
@@ -229,7 +227,7 @@ void Engine::cmd_reg_genmove(const Arguments& args, Response& response)
     response << get_board().to_string(move, false);
 }
 
-void Engine::cmd_savesgf(const Arguments& args)
+void Engine::cmd_savesgf(Arguments args)
 {
     ofstream out(args.get());
     PentobiTreeWriter writer(out, m_game.get_tree());
@@ -245,7 +243,7 @@ void Engine::cmd_savesgf(const Arguments& args)
     This command is similar to the command that is used by Quarry
     (http://home.gna.org/quarry/) to set a game at GTP engines that support
     multiple games. */
-void Engine::cmd_set_game(const Arguments& args)
+void Engine::cmd_set_game(Arguments args)
 {
     Variant variant;
     if (! parse_variant(args.get_line(), variant))
@@ -294,14 +292,14 @@ void Engine::genmove(Color c, Response& response)
     board_changed();
 }
 
-Color Engine::get_color_arg(const Arguments& args) const
+Color Engine::get_color_arg(Arguments args) const
 {
     if (args.get_size() > 1)
         throw Failure("too many arguments");
     return get_color_arg(args, 0);
 }
 
-Color Engine::get_color_arg(const Arguments& args, unsigned i) const
+Color Engine::get_color_arg(Arguments args, unsigned i) const
 {
     string s = args.get_tolower(i);
     auto& bd = get_board();
@@ -329,15 +327,15 @@ Color Engine::get_color_arg(const Arguments& args, unsigned i) const
 
 PlayerBase& Engine::get_player() const
 {
-    if (! m_player)
+    if (m_player == nullptr)
         throw Failure("no player set");
     return *m_player;
 }
 
-void Engine::play(Color c, const Arguments& args, unsigned arg_move_begin)
+void Engine::play(Color c, Arguments args, unsigned arg_move_begin)
 {
     auto& bd = get_board();
-    if (bd.get_nu_moves() >= Board::max_game_moves)
+    if (bd.get_nu_moves() >= Board::max_moves)
         throw Failure("too many moves");
     Move mv;
     try
