@@ -10,16 +10,14 @@
 
 #include "Game.h"
 
-#include "BoardUtil.h"
-#include "libboardgame_sgf/InvalidTree.h"
+#include "libboardgame_sgf/SgfError.h"
 #include "libboardgame_sgf/SgfUtil.h"
 
 namespace libpentobi_base {
 
-using libboardgame_sgf::InvalidTree;
+using libboardgame_sgf::SgfError;
 using libboardgame_sgf::util::back_to_main_variation;
 using libboardgame_sgf::util::is_main_variation;
-using libpentobi_base::boardutil::get_current_position_as_setup;
 
 //-----------------------------------------------------------------------------
 
@@ -30,8 +28,6 @@ Game::Game(Variant variant)
     init(variant);
 }
 
-Game::~Game() = default;
-
 void Game::add_setup(Color c, Move mv)
 {
     auto& node = m_tree.add_setup(*m_current, c, mv);
@@ -68,7 +64,7 @@ Color Game::get_to_play_default(const Game& game)
             return c;
         node = node->get_parent_or_null();
     }
-    while (node);
+    while (node != nullptr);
     return bd.get_effective_to_play(next);
 }
 
@@ -79,10 +75,10 @@ void Game::goto_node(const SgfNode& node)
     {
         update(node);
     }
-    catch (const InvalidTree&)
+    catch (const SgfError&)
     {
         // Try to restore the old state.
-        if (! old)
+        if (old == nullptr)
             m_current = &node;
         else
         {
@@ -90,7 +86,7 @@ void Game::goto_node(const SgfNode& node)
             {
                 update(*old);
             }
-            catch (const InvalidTree&)
+            catch (const SgfError&)
             {
             }
         }
@@ -134,7 +130,7 @@ void Game::play(ColorMove mv, bool always_create_new_node)
     const SgfNode* child = nullptr;
     if (! always_create_new_node)
         child = m_tree.find_child_with_move(*m_current, mv);
-    if (child)
+    if (child != nullptr)
         m_current = child;
     else
     {
