@@ -29,11 +29,13 @@ using libboardgame_sgf::SgfNode;
 bool get_move(const SgfNode& node, Variant variant, Color& c,
               MovePoints& points);
 
+bool has_move(const SgfNode& node, Variant variant);
+
 /** Check if a node has setup properties (not including the PL property). */
 bool has_setup(const SgfNode& node);
 
 /** Get the color to play in a setup position (PL property). */
-bool get_player(const SgfNode& node, Color& c);
+bool get_player(const SgfNode& node, Color::IntType nu_colors, Color& c);
 
 //-----------------------------------------------------------------------------
 
