@@ -19,7 +19,8 @@ namespace sgf_util {
 
 const char* get_color_id(Variant variant, Color c)
 {
-    if (variant == Variant::duo || variant == Variant::junior)
+    static_assert(Color::range == 4, "");
+    if (get_nu_colors(variant) == 2)
         return c == Color(0) ? "B" : "W";
     if (c == Color(0))
         return "1";
@@ -33,7 +34,8 @@ const char* get_color_id(Variant variant, Color c)
 
 const char* get_setup_id(Variant variant, Color c)
 {
-    if (variant == Variant::duo || variant == Variant::junior)
+    static_assert(Color::range == 4, "");
+    if (get_nu_colors(variant) == 2)
         return c == Color(0) ? "AB" : "AW";
     if (c == Color(0))
         return "A1";
