@@ -12,13 +12,11 @@
 
 #include "BoardUpdater.h"
 #include "BoardUtil.h"
-#include "libboardgame_util/StringUtil.h"
 
 namespace libpentobi_base {
 
-using libboardgame_sgf::InvalidPropertyValue;
-using libboardgame_sgf::InvalidTree;
-using libboardgame_util::to_string;
+using libboardgame_sgf::InvalidProperty;
+using libboardgame_sgf::SgfError;
 using libpentobi_base::boardutil::get_current_position_as_setup;
 
 //-----------------------------------------------------------------------------
@@ -30,7 +28,7 @@ PentobiTree::PentobiTree(Variant variant)
 
 PentobiTree::PentobiTree(unique_ptr<SgfNode>& root)
 {
-    init(root);
+    PentobiTree::init(root);
 }
 
 const SgfNode& PentobiTree::add_setup(const SgfNode& node, Color c, Move mv)
@@ -40,13 +38,16 @@ const SgfNode& PentobiTree::add_setup(const SgfNode& node, Color c, Move mv)
         result = &create_new_child(node);
     else
         result = &node;
-    Setup::PlacementList add_empty = get_setup_property(*result, "AE");
+    auto add_empty = get_setup_property(*result, "AE");
     if (add_empty.remove(mv))
         set_setup_property(*result, "AE", add_empty);
     auto id = get_setup_prop_id(c);
-    Setup::PlacementList add_color = get_setup_property(*result, id);
-    if (add_color.include(mv))
+    auto add_color = get_setup_property(*result, id);
+    if (! add_color.contains(mv) && add_color.size() < add_color.max_size)
+    {
+        add_color.push_back(mv);
         set_setup_property(*result, id, add_color);
+    }
     return *result;
 }
 
@@ -72,7 +73,7 @@ ColorMove PentobiTree::get_move(const SgfNode& node) const
         return ColorMove::null();
     Move mv;
     if (! m_bc->find_move(points, mv))
-        throw InvalidTree("Tree contains illegal move");
+        throw SgfError("Tree contains illegal move");
     return ColorMove(c, mv);
 }
 
@@ -124,14 +125,14 @@ Setup::PlacementList PentobiTree::get_setup_property(const SgfNode& node,
         for (auto& s : node.get_multi_property(id))
         {
             if (result.size() == result.max_size)
-                throw InvalidPropertyValue(id, s);
+                throw InvalidProperty(id, s);
             try
             {
                 result.push_back(m_bc->from_string(s));
             }
             catch (const runtime_error&)
             {
-                throw InvalidPropertyValue(id, s);
+                throw InvalidProperty(id, s);
             }
         }
     return result;
@@ -142,7 +143,7 @@ Variant PentobiTree::get_variant(const SgfNode& root)
     string game = root.get_property("GM");
     Variant variant;
     if (! parse_variant(game, variant))
-        throw InvalidPropertyValue("GM", game);
+        throw InvalidProperty("GM", game);
     return variant;
 }
 
@@ -155,7 +156,7 @@ bool PentobiTree::has_main_variation_moves() const
             return true;
         node = node->get_first_child_or_null();
     }
-    while (node);
+    while (node != nullptr);
     return false;
 }
 
@@ -192,7 +193,7 @@ void PentobiTree::keep_only_subtree(const SgfNode& node)
     if (! create_new_setup)
     {
         auto current = node.get_parent_or_null();
-        while (current)
+        while (current != nullptr)
         {
             if (has_move(*current) || node_util::has_setup(*current))
             {
@@ -204,7 +205,7 @@ void PentobiTree::keep_only_subtree(const SgfNode& node)
     }
     if (create_new_setup)
     {
-        unique_ptr<Board> bd(new Board(m_variant));
+        auto bd = make_unique<Board>(m_variant);
         BoardUpdater updater;
         updater.update(*bd, *this, node);
         Setup setup;
@@ -245,9 +246,12 @@ const SgfNode& PentobiTree::remove_setup(const SgfNode& node, Color c,
         set_setup_property(*result, id, add_color);
     else
     {
-        Setup::PlacementList add_empty = get_setup_property(*result, "AE");
-        if (add_empty.include(mv))
+        auto add_empty = get_setup_property(*result, "AE");
+        if (! add_empty.contains(mv) && add_empty.size() < add_empty.max_size)
+        {
+            add_empty.push_back(mv);
             set_setup_property(*result, "AE", add_empty);
+        }
     }
     return *result;
 }
@@ -346,7 +350,7 @@ void PentobiTree::set_setup(const SgfNode& node, const Setup& setup)
 }
 
 void PentobiTree::set_setup_property(const SgfNode& node, const char* id,
-                              const Setup::PlacementList& placements)
+                                     const Setup::PlacementList& placements)
 {
     if (placements.empty())
     {
@@ -354,6 +358,7 @@ void PentobiTree::set_setup_property(const SgfNode& node, const char* id,
         return;
     }
     vector<string> values;
+    values.reserve(placements.size());
     for (Move mv : placements)
         values.push_back(m_bc->to_string(mv, false));
     set_property(node, id, values);
