@@ -87,7 +87,7 @@ NormalizedPoints normalize(const PiecePoints& points, unsigned point_type,
 
 PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
                      const Geometry& geo, const PieceTransforms& transforms,
-                     PieceSet piece_set, const CoordPoint& label_pos,
+                     PieceSet piece_set, CoordPoint label_pos,
                      unsigned nu_instances)
     : m_nu_instances(nu_instances),
       m_points(points),
@@ -100,9 +100,12 @@ PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
     if (log_piece_creation)
         LIBBOARDGAME_LOG("Creating transformations for piece ", name, ' ',
                          points);
+    auto& all_transforms = transforms.get_all();
     vector<NormalizedPoints> all_transformed_points;
+    all_transformed_points.reserve(all_transforms.size());
+    m_uniq_transforms.reserve(all_transforms.size()); // Upper limit
     PiecePoints transformed_points;
-    for (const Transform* transform : transforms.get_all())
+    for (auto transform : all_transforms)
     {
         if (log_piece_creation)
             LIBBOARDGAME_LOG("Transformation ", get_type_name(*transform));
@@ -212,8 +215,7 @@ const Transform* PieceInfo::get_next_transform(const Transform* transform) const
     LIBBOARDGAME_ASSERT(pos != end);
     if (pos + 1 == end)
         return *begin;
-    else
-        return *(pos + 1);
+    return *(pos + 1);
 }
 
 const Transform* PieceInfo::get_previous_transform(
@@ -226,8 +228,7 @@ const Transform* PieceInfo::get_previous_transform(
     LIBBOARDGAME_ASSERT(pos != end);
     if (pos == begin)
         return *(end - 1);
-    else
-        return *(pos - 1);
+    return *(pos - 1);
 }
 
 //-----------------------------------------------------------------------------
