@@ -26,7 +26,7 @@ using libboardgame_util::ArrayList;
 
 //-----------------------------------------------------------------------------
 
-typedef float ScoreType;
+using ScoreType = float;
 
 //-----------------------------------------------------------------------------
 
@@ -45,7 +45,7 @@ public:
     /** Maximum number of instances of a piece per player. */
     static const unsigned max_instances = 3;
 
-    typedef ArrayList<CoordPoint, max_size> Points;
+    using Points = ArrayList<CoordPoint, max_size>;
 
 
     /** Constructor.
@@ -58,7 +58,7 @@ public:
         @param nu_instances The number of instances of the piece per player. */
     PieceInfo(const string& name, const Points& points,
               const Geometry& geo, const PieceTransforms& transforms,
-              PieceSet piece_set, const CoordPoint& label_pos,
+              PieceSet piece_set, CoordPoint label_pos,
               unsigned nu_instances = 1);
 
     const string& get_name() const { return m_name; }
@@ -127,7 +127,7 @@ private:
 
 //-----------------------------------------------------------------------------
 
-typedef PieceInfo::Points PiecePoints;
+using PiecePoints = PieceInfo::Points;
 
 //-----------------------------------------------------------------------------
 
