@@ -17,9 +17,7 @@
 
 using namespace std;
 using libboardgame_util::ArrayList;
-using libpentobi_base::BoardType;
 using libpentobi_base::CallistoGeometry;
-using libpentobi_base::Move;
 using libpentobi_base::PieceSet;
 using libpentobi_base::PointState;
 
@@ -38,8 +36,6 @@ BoardPainter::BoardPainter()
     m_fontCoordLabels.setStretch(QFont::SemiCondensed);
 }
 
-BoardPainter::~BoardPainter() = default;
-
 CoordPoint BoardPainter::getCoordPoint(int x, int y)
 {
     if (! m_hasPainted)
@@ -48,8 +44,7 @@ CoordPoint BoardPainter::getCoordPoint(int x, int y)
     y = static_cast<int>((y - m_boardOffset.y()) / m_fieldHeight);
     if (x < 0 || x >= m_width || y < 0 || y >= m_height)
         return CoordPoint::null();
-    else
-        return CoordPoint(x, y);
+    return CoordPoint(x, y);
 }
 
 void BoardPainter::paintCoordinates(QPainter& painter)
@@ -389,7 +384,7 @@ void BoardPainter::paintMarks(QPainter& painter,
                               Variant variant, const Grid<int>& marks)
 {
     for (Point p : *m_geo)
-        if (marks[p] & (dot | circle))
+        if ((marks[p] & (dot | circle)) != 0)
         {
             qreal x = (static_cast<float>(m_geo->get_x(p)) + 0.5f)
                     * m_fieldWidth;
@@ -434,7 +429,7 @@ void BoardPainter::paintMarks(QPainter& painter,
                 size = 0.12 * m_fieldHeight;
             QColor color = Util::getMarkColor(variant, pointState[p]);
             qreal penWidth = 0.05 * m_fieldHeight;
-            if (marks[p] & dot)
+            if ((marks[p] & dot) != 0)
             {
                 color.setAlphaF(0.5);
                 painter.setPen(Qt::NoPen);
@@ -541,9 +536,9 @@ void BoardPainter::paintPieces(QPainter& painter,
         }
     }
     paintStartingPoints(painter, m_variant, pointState, isFirstPiece);
-    if (marks)
+    if (marks != nullptr)
         paintMarks(painter, pointState, m_variant, *marks);
-    if (labels)
+    if (labels != nullptr)
         paintLabels(painter, pointState, m_variant, *labels);
     painter.restore();
 }
@@ -575,8 +570,8 @@ void BoardPainter::paintSelectedPiece(QPainter& painter, Color c,
     {
         if (p.is_null())
             continue;
-        auto x = m_geo->get_x(p);
-        auto y = m_geo->get_y(p);
+        int x = m_geo->get_x(p);
+        int y = m_geo->get_y(p);
         auto pointType = m_geo->get_point_type(p);
         qreal fieldX = x * m_fieldWidth;
         qreal fieldY = y * m_fieldHeight;
@@ -617,9 +612,9 @@ void BoardPainter::paintSelectedPiece(QPainter& painter, Color c,
                                      alpha, saturation, flat);
         else if (m_isCallisto)
         {
-            bool hasRight = (m_geo->is_onboard(CoordPoint(x + 1, y))
+            bool hasRight = (m_geo->is_onboard(x + 1, y)
                              && points.contains(m_geo->get_point(x + 1, y)));
-            bool hasDown = (m_geo->is_onboard(CoordPoint(x, y + 1))
+            bool hasDown = (m_geo->is_onboard(x, y + 1)
                             && points.contains(m_geo->get_point(x, y + 1)));
             Util::paintColorSquareCallisto(painter, m_variant, c, fieldX,
                                            fieldY, m_fieldWidth, hasRight,
@@ -635,13 +630,13 @@ void BoardPainter::paintSelectedPiece(QPainter& painter, Color c,
         {
             auto x = m_geo->get_x(p);
             auto y = m_geo->get_y(p);
-            bool hasLeft = (m_geo->is_onboard(CoordPoint(x - 1, y))
+            bool hasLeft = (m_geo->is_onboard(x - 1, y)
                             && points.contains(m_geo->get_point(x - 1, y)));
-            bool hasRight = (m_geo->is_onboard(CoordPoint(x + 1, y))
+            bool hasRight = (m_geo->is_onboard(x + 1, y)
                              && points.contains(m_geo->get_point(x + 1, y)));
-            bool hasUp = (m_geo->is_onboard(CoordPoint(x, y - 1))
+            bool hasUp = (m_geo->is_onboard(x, y - 1)
                           && points.contains(m_geo->get_point(x, y - 1)));
-            bool hasDown = (m_geo->is_onboard(CoordPoint(x, y + 1))
+            bool hasDown = (m_geo->is_onboard(x, y + 1)
                             && points.contains(m_geo->get_point(x, y + 1)));
             Util::paintJunction(painter, m_variant, c, x * m_fieldWidth,
                                 y * m_fieldHeight, m_fieldWidth, m_fieldHeight,
@@ -653,7 +648,7 @@ void BoardPainter::paintSelectedPiece(QPainter& painter, Color c,
 
 void BoardPainter::paintStartingPoints(QPainter& painter, Variant variant,
                                        const Grid<PointState>& pointState,
-                                       const ColorMap<bool>& isFirstPiece)
+                                       ColorMap<bool> isFirstPiece)
 {
     m_startingPoints.init(variant, *m_geo);
     auto colors = get_colors(variant);
