@@ -44,8 +44,6 @@ public:
 
     BoardPainter();
 
-    ~BoardPainter();
-
     void setCoordinates(bool enable) { m_coordinates = enable; }
 
     void setCoordinateColor(const QColor& color) { m_coordinateColor = color; }
@@ -142,7 +140,7 @@ private:
 
     void paintStartingPoints(QPainter& painter, Variant variant,
                              const Grid<PointState>& pointState,
-                             const ColorMap<bool>& isFirstPiece);
+                             ColorMap<bool> isFirstPiece);
 };
 
 //-----------------------------------------------------------------------------
