@@ -23,7 +23,6 @@ using libpentobi_base::MovePoints;
 using libpentobi_base::PiecePoints;
 using libpentobi_base::PieceSet;
 using libpentobi_base::Point;
-using libpentobi_base::PointState;
 
 //-----------------------------------------------------------------------------
 
@@ -37,7 +36,7 @@ bool allPointEmpty(const Board& bd, Move mv)
     return true;
 }
 
-QPixmap* createPixmap(const QPainter& painter, const QSize& size)
+QPixmap* createPixmap(const QPainter& painter, QSize size)
 {
     auto devicePixelRatio = painter.device()->devicePixelRatio();
     auto pixmap = new QPixmap(devicePixelRatio * size);
@@ -54,8 +53,8 @@ GuiBoard::GuiBoard(QWidget* parent, const Board& bd)
       m_bd(bd)
 {
     setMinimumSize(350, 350);
-    connect(&m_currentMoveShownAnimationTimer, SIGNAL(timeout()),
-            SLOT(showMoveAnimation()));
+    connect(&m_currentMoveShownAnimationTimer, &QTimer::timeout,
+            this, &GuiBoard::showMoveAnimation);
 }
 
 void GuiBoard::changeEvent(QEvent* event)
@@ -142,14 +141,13 @@ Move GuiBoard::findSelectedPieceMove()
             || (! m_freePlacement
                 && ! m_bd.is_legal(m_selectedPieceColor, mv)))
         return Move::null();
-    else
-        return mv;
+    return mv;
 }
 
 bool GuiBoard::isSelectedPiecePartiallyOnBoard(CoordPoint offset) const
 {
     if (m_selectedPiece.is_null() || offset.is_null()
-            || ! m_selectedPieceTransform)
+            || (m_selectedPieceTransform == nullptr))
         return false;
     auto& points = m_bd.get_piece_info(m_selectedPiece).get_points();
     auto& geo = m_bd.get_geometry();
@@ -169,8 +167,9 @@ bool GuiBoard::isSelectedPiecePartiallyOnBoard(CoordPoint offset) const
     return false;
 }
 
-void GuiBoard::leaveEvent(QEvent*)
+void GuiBoard::leaveEvent(QEvent* event)
 {
+    LIBBOARDGAME_UNUSED(event);
     m_selectedPieceOffset = CoordPoint::null();
     setSelectedPiecePoints();
 }
@@ -315,8 +314,9 @@ void GuiBoard::movePieceUp()
     }
 }
 
-void GuiBoard::paintEvent(QPaintEvent*)
+void GuiBoard::paintEvent(QPaintEvent* event)
 {
+    LIBBOARDGAME_UNUSED(event);
     if (! m_isInitialized)
         return;
     QPainter painter(this);
@@ -452,7 +452,7 @@ void GuiBoard::setSelectedPieceOffset(const QMouseEvent& event)
     instead of to the left.
     @param preferDownShift Prefer a downward geometry-matching shift
     instead of upward. */
-void GuiBoard::setSelectedPieceOffset(const CoordPoint& wantedOffset,
+void GuiBoard::setSelectedPieceOffset(CoordPoint wantedOffset,
                                       bool preferRightShift,
                                       bool preferDownShift)
 {
@@ -494,8 +494,8 @@ void GuiBoard::setSelectedPiecePoints()
     if (! m_selectedPiece.is_null() && ! m_selectedPieceOffset.is_null())
     {
         auto& geo = m_bd.get_geometry();
-        int width = static_cast<int>(geo.get_width());
-        int height = static_cast<int>(geo.get_height());
+        auto width = static_cast<int>(geo.get_width());
+        auto height = static_cast<int>(geo.get_height());
         for (CoordPoint p : m_bd.get_piece_info(m_selectedPiece).get_points())
         {
             p = m_selectedPieceTransform->get_transformed(p);
@@ -525,8 +525,8 @@ void GuiBoard::setSelectedPieceTransform(const Transform* transform)
     setSelectedPieceOffset(wantedOffset, preferRightShift, preferDownShift);
 
     // Shift towards center if completely outside board
-    int width = static_cast<int>(geo.get_width());
-    int height = static_cast<int>(geo.get_height());
+    auto width = static_cast<int>(geo.get_width());
+    auto height = static_cast<int>(geo.get_height());
     while (m_selectedPieceOffset.is_null())
     {
         preferRightShift = wantedOffset.x < width / 2;
