@@ -17,7 +17,7 @@ namespace gui_board_util {
 
 using libpentobi_base::ColorMove;
 using libpentobi_base::PentobiTree;
-using libboardgame_sgf::InvalidTree;
+using libboardgame_sgf::SgfError;
 using libboardgame_sgf::SgfNode;
 using libboardgame_sgf::util::is_main_variation;
 using libboardgame_sgf::util::get_move_annotation;
@@ -37,7 +37,7 @@ bool getVariationIndex(const PentobiTree& tree, const SgfNode& node,
                        unsigned& moveIndex)
 {
     auto parent = node.get_parent_or_null();
-    if (! parent || parent->has_single_child())
+    if ((parent == nullptr) || parent->has_single_child())
         return false;
     unsigned nuSiblingMoves = 0;
     moveIndex = 0;
@@ -108,9 +108,9 @@ void setMarkup(GuiBoard& guiBoard, const Game& game, unsigned markMovesBegin,
             }
             node = node->get_parent_or_null();
         }
-        while (node);
+        while (node != nullptr);
     }
-    catch (const InvalidTree&)
+    catch (const SgfError&)
     {
     }
 }
