@@ -19,12 +19,9 @@
 using libboardgame_base::CoordPoint;
 using libboardgame_base::geometry_util::type_match_shift;
 using libboardgame_util::trim;
-using libpentobi_base::BoardConst;
-using libpentobi_base::BoardType;
 using libpentobi_base::Geometry;
 using libpentobi_base::PieceMap;
 using libpentobi_base::PieceSet;
-using libpentobi_base::Variant;
 
 //-----------------------------------------------------------------------------
 
@@ -256,8 +253,8 @@ void PieceSelector::mousePressEvent(QMouseEvent* event)
     if (pixelX < 0 || pixelX >= m_selectorWidth
         || pixelY < 0 || pixelY >= m_selectorHeight)
         return;
-    int x = static_cast<int>(pixelX / m_fieldWidth);
-    int y = static_cast<int>(pixelY / m_fieldHeight);
+    auto x = static_cast<int>(pixelX / m_fieldWidth);
+    auto y = static_cast<int>(pixelY / m_fieldHeight);
     Piece piece = m_piece[x][y];
     if (piece.is_null() || m_disabled[x][y])
         return;
@@ -265,8 +262,9 @@ void PieceSelector::mousePressEvent(QMouseEvent* event)
     emit pieceSelected(m_color, piece, m_transform[x][y]);
 }
 
-void PieceSelector::paintEvent(QPaintEvent*)
+void PieceSelector::paintEvent(QPaintEvent* event)
 {
+    LIBBOARDGAME_UNUSED(event);
     setDisabledStatus(m_disabled);
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing, true);
