@@ -17,15 +17,10 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-SameHeightLayout::SameHeightLayout(QWidget* parent)
-    : QLayout(parent)
-{
-}
-
 SameHeightLayout::~SameHeightLayout()
 {
     QLayoutItem* item;
-    while ((item = takeAt(0)))
+    while ((item = SameHeightLayout::takeAt(0)) != nullptr)
         delete item;
 }
 
@@ -76,7 +71,7 @@ int SameHeightLayout::getSpacing() const
     // spacing is inherited from the parent layout, or from the style settings
     // for the parent widget."
     int result = spacing();
-    if (result < 0 && parentWidget())
+    if (result < 0 && (parentWidget() != nullptr))
         result = parentWidget()->style()->layoutSpacing(QSizePolicy::Frame,
                                                         QSizePolicy::Frame,
                                                         Qt::Vertical);
@@ -98,7 +93,7 @@ QLayoutItem* SameHeightLayout::takeAt(int i)
 void SameHeightLayout::setGeometry(const QRect& rect)
 {
     QLayout::setGeometry(rect);
-    if (m_list.size() == 0)
+    if (m_list.empty())
         return;
     int count = m_list.count();
     int width = rect.width();
