@@ -24,6 +24,10 @@ const QColor red(230, 62, 44);
 
 const QColor yellow(235, 205, 35);
 
+const QColor purple(161, 44, 207);
+
+const QColor orange(240, 173, 26);
+
 const QColor gray(174, 167, 172);
 
 void setAlphaSaturation(QColor& c, qreal alpha, qreal saturation)
@@ -35,8 +39,8 @@ void setAlphaSaturation(QColor& c, qreal alpha, qreal saturation)
         c.setAlphaF(alpha);
 }
 
-void paintDot(QPainter& painter, QColor color, qreal x, qreal y, qreal width,
-              qreal height, qreal size)
+void paintDot(QPainter& painter, const QColor& color, qreal x, qreal y,
+              qreal width, qreal height, qreal size)
 {
     painter.save();
     painter.translate(x, y);
@@ -47,8 +51,8 @@ void paintDot(QPainter& painter, QColor color, qreal x, qreal y, qreal width,
 }
 
 void paintGembloQ(QPainter& painter, unsigned pointType, qreal x, qreal y,
-                  qreal width, QColor color, QColor upColor, QColor downColor,
-                  bool flat)
+                  qreal width, const QColor& color, const QColor& upColor,
+                  const QColor& downColor, bool flat)
 {
     painter.save();
     painter.translate(x, y);
@@ -335,8 +339,7 @@ QColor Util::getLabelColor(Variant variant, PointState s)
     QColor paintColor = getPaintColor(variant, c);
     if (paintColor == yellow || paintColor == green)
         return Qt::black;
-    else
-        return Qt::white;
+    return Qt::white;
 }
 
 QColor Util::getMarkColor(Variant variant, PointState s)
@@ -347,30 +350,36 @@ QColor Util::getMarkColor(Variant variant, PointState s)
     QColor paintColor = getPaintColor(variant, c);
     if (paintColor == yellow || paintColor == green)
         return QColor(51, 51, 51);
-    else
-        return Qt::white;
+    return Qt::white;
 }
 
 QColor Util::getPaintColor(Variant variant, Color c)
 {
+    if (variant == Variant::duo)
+        return c == Color(0) ? purple : orange;
+    if (variant == Variant::junior)
+        return c == Color(0) ? green : orange;
     if (get_nu_colors(variant) == 2)
         return c == Color(0) ? blue : green;
-    else
-    {
-        if (c == Color(0))
-            return blue;
-        if (c == Color(1))
-            return yellow;
-        if (c == Color(2))
-            return red;
-        LIBBOARDGAME_ASSERT(c == Color(3));
-        return green;
-    }
+    if (c == Color(0))
+        return blue;
+    if (c == Color(1))
+        return yellow;
+    if (c == Color(2))
+        return red;
+    LIBBOARDGAME_ASSERT(c == Color(3));
+    return green;
 }
 
 QString Util::getPlayerString(Variant variant, Color c)
 {
     auto i = c.to_int();
+    if (variant == Variant::duo)
+        return i == 0 ? qApp->translate("Util", "Purple")
+                      : qApp->translate("Util", "Orange");
+    if (variant == Variant::junior)
+        return i == 0 ? qApp->translate("Util", "Green")
+                      : qApp->translate("Util", "Orange");
     if (get_nu_colors(variant) == 2)
         return i == 0 ? qApp->translate("Util", "Blue")
                       : qApp->translate("Util", "Green");
