@@ -16,8 +16,7 @@
 
 namespace libpentobi_mcts {
 
-using libboardgame_sgf::InvalidTree;
-using libboardgame_sgf::SgfNode;
+using libboardgame_sgf::SgfError;
 using libboardgame_util::clear_abort;
 using libboardgame_util::get_abort;
 using libboardgame_util::WallTimeSource;
@@ -32,7 +31,7 @@ void AnalyzeGame::clear()
 }
 
 void AnalyzeGame::run(const Game& game, Search& search, size_t nu_simulations,
-                      function<void(unsigned,unsigned)> progress_callback)
+                      const function<void(unsigned,unsigned)>& progress_callback)
 {
     m_variant = game.get_variant();
     m_moves.clear();
@@ -49,7 +48,7 @@ void AnalyzeGame::run(const Game& game, Search& search, size_t nu_simulations,
             ++total_moves;
         node = node->get_first_child_or_null();
     }
-    while (node);
+    while (node != nullptr);
     WallTimeSource time_source;
     clear_abort();
     node = &root;
@@ -73,7 +72,7 @@ void AnalyzeGame::run(const Game& game, Search& search, size_t nu_simulations,
                 {
                     updater.update(*bd, tree, node->get_parent());
                     LIBBOARDGAME_LOG("Analyzing move ", bd->get_nu_moves());
-                    const Float max_count = Float(nu_simulations);
+                    const auto max_count = Float(nu_simulations);
                     double max_time = 0;
                     // Set min_simulations to a reasonable value because
                     // nu_simulations can be reached without having that many
@@ -89,7 +88,7 @@ void AnalyzeGame::run(const Game& game, Search& search, size_t nu_simulations,
                     m_moves.push_back(mv);
                     m_values.push_back(search.get_root_val().get_mean());
                 }
-                catch (const InvalidTree&)
+                catch (const SgfError&)
                 {
                     // BoardUpdater::update() can throw on invalid SGF tree
                     // read from external file. We simply abort the analysis.
@@ -100,7 +99,7 @@ void AnalyzeGame::run(const Game& game, Search& search, size_t nu_simulations,
         }
         node = node->get_first_child_or_null();
     }
-    while (node);
+    while (node != nullptr);
 }
 
 void AnalyzeGame::set(Variant variant, const vector<ColorMove>& moves,
