@@ -45,7 +45,7 @@ public:
         Should be fast and have enough space for the masks used. Note that
         logically, we want uint_fast32_t, but that is an 8-byte unsigned
         with GCC on Intel CPUs, which is *slower* than a 4-byte unsigned. */
-    typedef uint_least32_t IntType;
+    using IntType = uint_least32_t;
 
     /** The maximum number of local points for a move.
         The number can be higher than PieceInfo::max_size (see class
@@ -91,7 +91,6 @@ public:
 
     friend class Compute;
 
-    PlayoutFeatures();
 
     /** Initialize snapshot with forbidden state. */
     void init_snapshot(const Board& bd, Color c);
@@ -116,8 +115,24 @@ private:
 
     /** Points with non-zero local value. */
     PointList m_local_points;
+
+
+    void add_local(const Board& bd, Point p, Color to_play,
+                   unsigned& nu_local);
 };
 
+
+inline void PlayoutFeatures::add_local(const Board& bd, Point p, Color to_play,
+                                       unsigned& nu_local)
+{
+    if (m_point_value[p] == 0)
+    {
+        m_local_points.get_unchecked(nu_local++) = p;
+        m_point_value[p] =
+                1 + static_cast<IntType>(bd.is_attach_point(p, to_play));
+    }
+}
+
 inline void PlayoutFeatures::init_snapshot(const Board& bd, Color c)
 {
     m_point_value[Point::null()] = 0;
@@ -186,36 +201,20 @@ inline void PlayoutFeatures::set_local(const Board& bd)
         {
             if (is_forbidden[*j])
                 continue;
-            if (m_point_value[*j] == 0)
-            {
-                m_local_points.get_unchecked(nu_local++) = *j;
-                m_point_value[*j] =
-                        1 + static_cast<IntType>(
-                            bd.is_attach_point(*j, to_play));
-            }
+            add_local(bd, *j, to_play, nu_local);
             if (MAX_SIZE == 7 || IS_CALLISTO)
             {
                 // Nexos or Callisto don't use adjacent points, use 2nd-order
                 // "diagonal" points instead
                 LIBBOARDGAME_ASSERT(geo.get_adj(*j).empty());
                 for (Point k : geo.get_diag(*j))
-                    if (! is_forbidden[k] && m_point_value[k] == 0)
-                    {
-                        m_local_points.get_unchecked(nu_local++) = k;
-                        m_point_value[k] =
-                                1 + static_cast<IntType>(
-                                    bd.is_attach_point(k, to_play));
-                    }
+                    if (! is_forbidden[k])
+                        add_local(bd, k, to_play, nu_local);
             }
             else
                 for (Point k : geo.get_adj(*j))
-                    if (! is_forbidden[k] && m_point_value[k] == 0)
-                    {
-                        m_local_points.get_unchecked(nu_local++) = k;
-                        m_point_value[k] =
-                                1 + static_cast<IntType>(
-                                    bd.is_attach_point(k, to_play));
-                    }
+                    if (! is_forbidden[k])
+                        add_local(bd, k, to_play, nu_local);
         }
         while (++j != end);
     }
