@@ -8,45 +8,54 @@
 #define LIBPENTOBI_MCTS_PRIOR_KNOWLEDGE_H
 
 #include "Float.h"
+#include "LocalPoints.h"
 #include "SearchParamConst.h"
 #include "libboardgame_mcts/Tree.h"
-#include "libboardgame_util/MathUtil.h"
 #include "libpentobi_base/Board.h"
 
 namespace libpentobi_mcts {
 
 using namespace std;
-using libboardgame_util::fast_exp;
 using libpentobi_base::Board;
 using libpentobi_base::BoardConst;
 using libpentobi_base::ColorMap;
 using libpentobi_base::ColorMove;
+using libpentobi_base::Geometry;
 using libpentobi_base::Grid;
 using libpentobi_base::GridExt;
 using libpentobi_base::Move;
 using libpentobi_base::MoveList;
+using libpentobi_base::Piece;
+using libpentobi_base::PieceMap;
 using libpentobi_base::Point;
 using libpentobi_base::PointList;
 using libpentobi_base::Variant;
 
 //-----------------------------------------------------------------------------
 
-/** Initializes newly created nodes with heuristic prior count and value. */
+/** Initializes newly created nodes with move prior, count and value.
+    Computes move priors of the form exp(phi*x) with a weight vector phi and a
+    feature vector x. These weights can be learned with softmax training from
+    existing games (see pentobi/src/learn_tool).
+
+    The move generation also prunes certain moves in some game variants (e.g.
+    opening moves that don't go towards the center). */
 class PriorKnowledge
 {
 public:
-    typedef libboardgame_mcts::Node<Move, Float, SearchParamConst::multithread>
-    Node;
+    using Node =
+        libboardgame_mcts::Node<Move, Float, SearchParamConst::multithread>;
 
-    typedef libboardgame_mcts::Tree<Node> Tree;
+    using Tree = libboardgame_mcts::Tree<Node>;
 
-    PriorKnowledge();
+
+    explicit PriorKnowledge(const Board& bd);
 
     void start_search(const Board& bd);
 
     /** Generate children nodes initialized with prior knowledge.
         @return false If the tree has not enough capacity for the children. */
-    template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
+    template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH, bool IS_CALLISTO>
     bool gen_children(const Board& bd, const MoveList& moves,
                       bool is_symmetry_broken, Tree::NodeExpander& expander,
                       Float root_val);
@@ -54,10 +63,8 @@ public:
 private:
     struct MoveFeatures
     {
-        /** Heuristic value of the move expressed in score points. */
-        Float heuristic;
-
-        bool is_local;
+        /** Heuristic unnormalized probability of the move. */
+        Float gamma;
 
         /** Does the move touch a piece of the same player? */
         bool connect;
@@ -69,39 +76,81 @@ private:
 
     array<MoveFeatures, Move::range> m_features;
 
-    /** Maximum of Features::heuristic for all moves. */
-    Float m_max_heuristic;
+    /** @name Gammas for move scores. */
+    /** @{ */
+
+    Float m_gamma_point_other;
+
+    /** Point is opponent attach point or adjacent to it. */
+    Float m_gamma_point_opp_attach_or_nb;
+
+    /** Point is attach point of second color. */
+    Float m_gamma_point_second_color_attach;
+
+    /** Adjacent point connects two own colors. */
+    Float m_gamma_adj_connect;
+
+    /** Adjacent point is occupied by opponent. */
+    Float m_gamma_adj_occupied_other;
+
+    Float m_gamma_adj_forbidden_other;
+
+    /** Adjacent point is own attach point. */
+    Float m_gamma_adj_own_attach;
+
+    /** Adjacent point is not already forbidden. */
+    Float m_gamma_adj_nonforbidden;
+
+    Float m_gamma_attach_to_play;
+
+    Float m_gamma_attach_forbidden_other;
+
+    /** Attach point is attach point of another own color. */
+    Float m_gamma_attach_second_color;
+
+    /** Move occupies an attach point of a recent opponent move. */
+    Float m_gamma_local;
+
+    PieceMap<Float> m_gamma_piece_score;
+
+    /** Attach point is nonforbidden and has n non-forbidden neighbors. */
+    array<Float, Geometry::max_adj + 1> m_gamma_attach_nonforbidden;
+
+    /** @} */ // @name
+
+    /** Maximum of Features::gamma for all moves. */
+    Float m_max_gamma;
+
+    /** Sum of Features::gamma for all moves. */
+    Float m_sum_gamma;
 
     bool m_has_connect_move;
 
     ColorMap<bool> m_check_dist_to_center;
 
+    Variant m_variant;
+
     unsigned m_dist_to_center_max_pieces;
 
     float m_min_dist_to_center;
 
     float m_max_dist_diff;
 
-    /** Marker for attach points of recent opponent moves. */
-    GridExt<bool> m_is_local;
-
-    /** Points in m_is_local with value greater zero. */
-    PointList m_local_points;
+    LocalPoints m_local_points;
 
     /** Distance to center heuristic. */
     GridExt<float> m_dist_to_center;
 
 
-    template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
+    template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH, bool IS_CALLISTO>
     void compute_features(const Board& bd, const MoveList& moves,
                           bool check_dist_to_center, bool check_connect);
 
-    template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
-    void init_local(const Board& bd);
+    void init_variant(const Board& bd);
 };
 
 
-template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
+template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH, bool IS_CALLISTO>
 void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
                                       bool check_dist_to_center,
                                       bool check_connect)
@@ -111,8 +160,8 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
     Color second_color;
     // connect_color is the 2nd color of the player in game variants with 2
     // colors per player (connecting to_play and connect_color is good) and
-    // to_play in other game variants (which disables the bonus without
-    // needing an extra check below because adj_point_value is not used for
+    // to_play in other game variants (which disables the feature without
+    // needing an extra check below because adj_value is not used for
     // pieces of to_play because it is illegal for to_play to play there).
     Color connect_color;
     if (variant == Variant::classic_3 && to_play.to_int() == 3)
@@ -130,39 +179,41 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
     auto move_info_array = bc.get_move_info_array();
     auto move_info_ext_array = bc.get_move_info_ext_array();
     auto& is_forbidden = bd.is_forbidden(to_play);
-    GridExt<Float> point_value;
-    point_value[Point::null()] = 0;
-    Grid<Float> attach_point_value;
-    Grid<Float> adj_point_value;
+    GridExt<Float> gamma_point;
+    gamma_point[Point::null()] = 1;
+    Grid<Float> gamma_attach;
+    Grid<Float> gamma_adj;
     for (Point p : geo)
     {
         auto s = bd.get_point_state(p);
         if (is_forbidden[p])
         {
+            // No need to initialize gamma_point[p] for forbidden points
             if (s != to_play)
-                attach_point_value[p] = -2.5;
+                gamma_attach[p] = m_gamma_attach_forbidden_other;
             else
-                attach_point_value[p] = 0.5;
+                gamma_attach[p] = m_gamma_attach_to_play;
             if (s == connect_color)
-                // Connecting own colors is good
-                adj_point_value[p] = 1;
+                gamma_adj[p] = m_gamma_adj_connect;
             else if (! s.is_empty())
-                // Touching opponent is better than playing elsewhere (no need to
-                // check if s == to_play, such moves are illegal)
-                adj_point_value[p] = 0.4f;
+                // Occupied by opponent (no need to check if s == to_play,
+                // such moves are illegal)
+                gamma_adj[p] = m_gamma_adj_occupied_other;
             else
-                adj_point_value[p] = 0;
+                gamma_adj[p] = m_gamma_adj_forbidden_other;
         }
         else
         {
-            point_value[p] = 1;
-            attach_point_value[p] = 0.5;
+            gamma_point[p] = m_gamma_point_other;
             if (bd.is_attach_point(p, to_play))
-                // Making own attach point forbidden is especially bad
-                adj_point_value[p] = -1;
+                gamma_adj[p] = m_gamma_adj_own_attach;
             else
-                // Creating new forbidden points is a bad thing
-                adj_point_value[p] = -0.1f;
+                gamma_adj[p] = m_gamma_adj_nonforbidden;
+            unsigned n = 0;
+            for (auto pa : geo.get_adj(p))
+                n+= 1u - static_cast<unsigned>(is_forbidden[pa]);
+            LIBBOARDGAME_ASSERT(n < m_gamma_attach_nonforbidden.size());
+            gamma_attach[p] = m_gamma_attach_nonforbidden[n];
         }
     }
     for (Color c : bd.get_colors())
@@ -173,52 +224,43 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
         for (Point p : bd.get_attach_points(c))
             if (! is_forbidden[p])
             {
-                // Occupying opponent attach points or points adjacent to them
-                // is very good
-                point_value[p] = 3.f;
+                gamma_point[p] = m_gamma_point_opp_attach_or_nb;
                 for (Point j : geo.get_adj(p))
                     if (! is_forbidden[j])
-                        point_value[j] = 3.f;
+                        gamma_point[j] = m_gamma_point_opp_attach_or_nb;
             }
     }
-    if (variant == Variant::classic_2
-            || (variant == Variant::classic_3 && second_color != to_play))
+    if (second_color != to_play)
     {
         auto& is_forbidden_second_color = bd.is_forbidden(second_color);
         for (Point p : bd.get_attach_points(second_color))
             if (! is_forbidden_second_color[p])
             {
-                // Occupying attach points of second color is bad
-                point_value[p] -= 3.f;
+                gamma_point[p] *= m_gamma_point_second_color_attach;
                 if (! is_forbidden[p])
-                    // Sharing an attach point with second color is bad
-                    attach_point_value[p] -= 1.f;
+                    gamma_attach[p] *= m_gamma_attach_second_color;
             }
     }
-    m_max_heuristic = -numeric_limits<Float>::max();
+    m_max_gamma = -numeric_limits<Float>::max();
+    m_sum_gamma = 0;
     m_min_dist_to_center = numeric_limits<unsigned short>::max();
     m_has_connect_move = false;
     for (unsigned i = 0; i < moves.size(); ++i)
     {
         auto mv = moves[i];
-        auto info = BoardConst::get_move_info<MAX_SIZE>(mv, move_info_array);
         auto& info_ext = BoardConst::get_move_info_ext<MAX_ADJ_ATTACH>(
                     mv, move_info_ext_array);
         auto& features = m_features[i];
+        auto& info = BoardConst::get_move_info<MAX_SIZE>(mv, move_info_array);
         auto j = info.begin();
-        Float heuristic = point_value[*j];
-        bool local = m_is_local[*j];
+        Float gamma = gamma_point[*j];
+        bool local = m_local_points.contains(*j);
         if (! check_dist_to_center)
             for (unsigned k = 1; k < MAX_SIZE; ++k)
             {
                 ++j;
-                heuristic += point_value[*j];
-                // Logically, we mean: local = local || m_is_local[*j]
-                // But this generates branches, which are bad for performance
-                // in this tight loop (unrolled by the compiler). So we use a
-                // bitwise OR, which works because C++ guarantees that
-                // true/false converts to 1/0.
-                local |= m_is_local[*j];
+                gamma *= gamma_point[*j];
+                local |= m_local_points.contains(*j);
             }
         else
         {
@@ -226,24 +268,34 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
             for (unsigned k = 1; k < MAX_SIZE; ++k)
             {
                 ++j;
-                heuristic += point_value[*j];
-                // See comment above about bitwise OR on bool
-                local |= m_is_local[*j];
+                gamma *= gamma_point[*j];
+                local |= m_local_points.contains(*j);
                 features.dist_to_center =
                     min(features.dist_to_center, m_dist_to_center[*j]);
             }
             m_min_dist_to_center =
                 min(m_min_dist_to_center, features.dist_to_center);
         }
+        if (local)
+            gamma *= m_gamma_local;
         j = info_ext.begin_attach();
         auto end = info_ext.end_attach();
-        heuristic += attach_point_value[*j];
+        gamma *= gamma_attach[*j];
         while (++j != end)
-            heuristic += attach_point_value[*j];
-        if (MAX_SIZE == 7) // Nexos
+            gamma *= gamma_attach[*j];
+        if (MAX_SIZE == 7 || IS_CALLISTO)
         {
+            // Nexos and Callisto don't use "adjacent" points, only "diagonal"
+            // Use the features of gamma_adj also for the attach points
             LIBBOARDGAME_ASSERT(info_ext.size_adj_points == 0);
             LIBBOARDGAME_ASSERT(! check_connect);
+            j = info_ext.begin_attach();
+            end = info_ext.end_attach();
+            for ( ; j != end; ++j)
+            {
+                gamma *= gamma_attach[*j];
+                gamma *= gamma_adj[*j];
+            }
         }
         else
         {
@@ -252,14 +304,14 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
             if (! check_connect)
             {
                 for ( ; j != end; ++j)
-                    heuristic += adj_point_value[*j];
+                    gamma *= gamma_adj[*j];
             }
             else
             {
                 features.connect = (bd.get_point_state(*j) == second_color);
                 for ( ; j != end; ++j)
                 {
-                    heuristic += adj_point_value[*j];
+                    gamma *= gamma_adj[*j];
                     if (bd.get_point_state(*j) == second_color)
                         features.connect = true;
                 }
@@ -267,29 +319,31 @@ void PriorKnowledge::compute_features(const Board& bd, const MoveList& moves,
                     m_has_connect_move = true;
             }
         }
-        if (heuristic > m_max_heuristic)
-            m_max_heuristic = heuristic;
-        features.heuristic = heuristic;
-        features.is_local = local;
+        gamma *= m_gamma_piece_score[info.get_piece()];
+        m_sum_gamma += gamma;
+        if (gamma > m_max_gamma)
+            m_max_gamma = gamma;
+        features.gamma = gamma;
     }
 }
 
-template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
+template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH, bool IS_CALLISTO>
 bool PriorKnowledge::gen_children(const Board& bd, const MoveList& moves,
                                   bool is_symmetry_broken,
                                   Tree::NodeExpander& expander, Float root_val)
 {
     if (moves.empty())
     {
-        // Add a pass move. The initialization value does not matter for a
-        // single child, but we need to use SearchParamConst::child_min_count
-        // for the count to avoid an assertion.
+        // Add a pass move. The in-tree phase of the search assumes alternating
+        // moves, because the color of a move is not stored in the nodes and
+        // it wouldn't know who is to play otherwise without generating moves.
         if (! expander.check_capacity(1))
             return false;
-        expander.add_child(Move::null(), root_val, 3);
+        expander.add_child(Move::null(), root_val,
+                           SearchParamConst::child_min_count, 1);
         return true;
     }
-    init_local<MAX_SIZE, MAX_ADJ_ATTACH>(bd);
+    m_local_points.init<MAX_SIZE, MAX_ADJ_ATTACH>(bd);
     auto to_play = bd.get_to_play();
     auto nu_onboard_pieces = bd.get_nu_onboard_pieces();
     bool check_dist_to_center =
@@ -297,11 +351,10 @@ bool PriorKnowledge::gen_children(const Board& bd, const MoveList& moves,
              && nu_onboard_pieces <= m_dist_to_center_max_pieces);
     bool check_connect =
         (bd.get_variant() == Variant::classic_2 && nu_onboard_pieces < 14);
-    compute_features<MAX_SIZE, MAX_ADJ_ATTACH>(bd, moves, check_dist_to_center,
-                                               check_connect);
+    compute_features<MAX_SIZE, MAX_ADJ_ATTACH, IS_CALLISTO>(
+                bd, moves, check_dist_to_center, check_connect);
     if (! m_has_connect_move)
         check_connect = false;
-    Move symmetric_mv = Move::null();
     bool has_symmetry_breaker = false;
     if (! is_symmetry_broken)
     {
@@ -310,9 +363,21 @@ bool PriorKnowledge::gen_children(const Board& bd, const MoveList& moves,
         {
             if (nu_moves > 0)
             {
+                // If a symmetric draw is still possible, encourage exploring
+                // the move that keeps the symmetry
                 ColorMove last = bd.get_move(nu_moves - 1);
-                symmetric_mv =
+                Move symmetric_mv =
                         bd.get_move_info_ext_2(last.move).symmetric_move;
+                for (unsigned i = 0; i < moves.size(); ++i)
+                    if (moves[i] == symmetric_mv)
+                    {
+                        m_sum_gamma -= m_features[i].gamma;
+                        m_features[i].gamma *= 100.f;
+                        m_sum_gamma += m_features[i].gamma;
+                        if (m_features[i].gamma > m_max_gamma)
+                            m_max_gamma = m_features[i].gamma;
+                        break;
+                    }
             }
         }
         else if (nu_moves > 0)
@@ -326,103 +391,33 @@ bool PriorKnowledge::gen_children(const Board& bd, const MoveList& moves,
     m_min_dist_to_center += m_max_dist_diff;
     if (! expander.check_capacity(static_cast<unsigned short>(moves.size())))
         return false;
+    auto inv_max_gamma = 1.f / m_max_gamma;
+    auto inv_sum_gamma = 1.f / m_sum_gamma;
+
     for (unsigned i = 0; i < moves.size(); ++i)
     {
         const auto& features = m_features[i];
-
         // Depending on the game variant, prune early moves that don't minimize
-        // dist to center and moves that don't connect in the middle if
-        // connection is possible
+        // dist to center and moves that don't connect in the middle
         if ((check_dist_to_center
              && features.dist_to_center > m_min_dist_to_center)
                 || (check_connect && ! features.connect))
             continue;
-
         auto mv = moves[i];
-
-        // Convert the heuristic, which is so far estimated in score points,
-        // into a win/loss value in [0..1] by making it relative to the
-        // heuristic of the best move and let it decrease exponentially with a
-        // certain width. We could use exp(-c*x) here, but we use
-        // 0.1+0.9*exp(-c*x) instead to avoid that the value is too close to
-        // 0, because then it might never get explored in practice if the bias
-        // term constant is small.
-        Float heuristic = m_max_heuristic - features.heuristic;
-        heuristic = 0.1f + 0.9f * fast_exp(-0.6f * heuristic);
-
-        // Initialize value from heuristic and root_val, each with a count
-        // of 1.5. If this is changed, SearchParamConst::child_min_count
-        // should be updated.
-        Float value = 1.5f * (heuristic + root_val);
-        Float count = 3;
-
-        // If a symmetric draw is still possible, encourage exploring a move
-        // that keeps or breaks the symmetry by adding 5 wins or 5 losses
-        // See also the comment in evaluate_playout()
-        if (! symmetric_mv.is_null())
-        {
-            if (mv == symmetric_mv)
-                value += 5;
-            count += 5;
-        }
-        else if (has_symmetry_breaker
-                 && ! bd.get_move_info_ext_2(mv).breaks_symmetry)
+        // If a symmetric draw is still possible, consider only moves that
+        // break the symmetry
+        if (has_symmetry_breaker
+                && ! bd.get_move_info_ext_2(mv).breaks_symmetry)
             continue;
-
-        // Add 1 win for moves that are local responses to recent opponent
-        // moves
-        if (features.is_local)
-        {
-            value += 1;
-            count += 1;
-        }
-
+        Float move_prior = features.gamma * inv_sum_gamma;
+        Float value = features.gamma * inv_max_gamma * root_val;
         LIBBOARDGAME_ASSERT(bd.is_legal(to_play, mv));
-        expander.add_child(mv, value / count, count);
+        expander.add_child(mv, value, SearchParamConst::child_min_count,
+                           move_prior);
     }
     return true;
 }
 
-template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH>
-inline void PriorKnowledge::init_local(const Board& bd)
-{
-    for (Point p : m_local_points)
-        m_is_local[p] = false;
-    unsigned nu_local = 0;
-    Color to_play = bd.get_to_play();
-    Color second_color;
-    if (bd.get_variant() == Variant::classic_3 && to_play.to_int() == 3)
-        second_color = Color(bd.get_alt_player());
-    else
-        second_color = bd.get_second_color(to_play);
-    auto& moves = bd.get_moves();
-    auto move_info_ext_array = bd.get_board_const().get_move_info_ext_array();
-    // Consider last 3 moves for local points (i.e. last 2 opponent moves in
-    // two-color variants)
-    auto end = moves.end();
-    auto begin = (end - moves.begin() < 3 ? moves.begin() : end - 3);
-    for (auto i = begin; i != end; ++i)
-    {
-        Color c = i->color;
-        if (c == to_play || c == second_color)
-            continue;
-        auto mv = i->move;
-        auto& is_forbidden = bd.is_forbidden(c);
-        auto& info_ext = BoardConst::get_move_info_ext<MAX_ADJ_ATTACH>(
-                    mv, move_info_ext_array);
-        auto j = info_ext.begin_attach();
-        auto end = info_ext.end_attach();
-        do
-            if (! is_forbidden[*j] && ! m_is_local[*j])
-            {
-                m_local_points.get_unchecked(nu_local++) = *j;
-                m_is_local[*j] = true;
-            }
-        while (++j != end);
-    }
-    m_local_points.resize(nu_local);
-}
-
 //-----------------------------------------------------------------------------
 
 } // namespace libpentobi_mcts
