@@ -45,16 +45,17 @@ using libpentobi_base::Variant;
 class State
 {
 public:
-    typedef libboardgame_mcts::Node<Move, Float, SearchParamConst::multithread>
-        Node;
+    using Node =
+        libboardgame_mcts::Node<Move, Float, SearchParamConst::multithread>;
 
-    typedef libboardgame_mcts::Tree<Node> Tree;
+    using Tree = libboardgame_mcts::Tree<Node>;
+
+    using LastGoodReply =
+        libboardgame_mcts::LastGoodReply<Move,
+                                         SearchParamConst::max_players,
+                                         SearchParamConst::lgr_hash_table_size,
+                                         SearchParamConst::multithread>;
 
-    typedef libboardgame_mcts::LastGoodReply<Move,
-                                             SearchParamConst::max_players,
-                                             SearchParamConst::lgr_hash_table_size,
-                                             SearchParamConst::multithread>
-        LastGoodReply;
 
     /** Constructor.
         @param initial_variant Game variant to initialize the internal
@@ -249,6 +250,7 @@ private:
 
     const PieceMap<bool>& get_is_piece_considered(Color c) const;
 
+    template<bool IS_CALLISTO>
     const Board::PiecesLeftList& get_pieces_considered(Color c);
 
     void init_gamma();
@@ -256,7 +258,7 @@ private:
     template<unsigned MAX_SIZE, unsigned MAX_ADJ_ATTACH, bool IS_CALLISTO>
     void init_moves_with_gamma(Color c);
 
-    template<unsigned MAX_SIZE>
+    template<unsigned MAX_SIZE, bool IS_CALLISTO>
     void init_moves_without_gamma(Color c);
 
     template<unsigned MAX_SIZE>
@@ -304,17 +306,12 @@ inline bool State::check_lgr(Move mv) const
     auto points = m_bd.get_move_points(mv);
     auto i = points.begin();
     auto end = points.end();
-    bool has_attach_point = false;
+    int has_attach_point = 0;
     do
     {
         if (m_bd.is_forbidden(*i, c))
             return false;
-        // Logically, we mean:
-        // has_attach_point = has_attach_point || is_attach_point(*i, c)
-        // But this generates branches, which are bad for performance in this
-        // tight loop (unrolled by the compiler). So we use a bitwise OR, which
-        // works because C++ guarantees that true/false converts to 1/0.
-        has_attach_point |= m_bd.is_attach_point(*i, c);
+        has_attach_point |= static_cast<int>(m_bd.is_attach_point(*i, c));
     }
     while (++i != end);
     if (m_is_callisto)
@@ -325,7 +322,7 @@ inline bool State::check_lgr(Move mv) const
         if (m_bd.get_nu_left_piece(c, one_piece) > 1 && piece != one_piece)
             return false;
     }
-    return has_attach_point;
+    return has_attach_point != 0;
 }
 
 inline void State::evaluate_playout(array<Float, 6>& result)
@@ -419,6 +416,43 @@ inline bool State::has_moves(Color c, Piece piece, Point p,
     return m_shared_const.precomp_moves[c].has_moves(piece, p, adj_status);
 }
 
+inline void State::play_in_tree(Move mv)
+{
+    Color to_play = m_bd.get_to_play();
+    if (! mv.is_null())
+    {
+        LIBBOARDGAME_ASSERT(m_bd.is_legal(to_play, mv));
+        m_nu_passes = 0;
+        if (m_max_piece_size == 5)
+        {
+            m_bd.play<5, 16>(to_play, mv);
+            update_playout_features<5, 16>(to_play, mv);
+        }
+        else if (m_max_piece_size == 6)
+        {
+            m_bd.play<6, 22>(to_play, mv);
+            update_playout_features<6, 22>(to_play, mv);
+        }
+        else if (m_max_piece_size == 7)
+        {
+            m_bd.play<7, 12>(to_play, mv);
+            update_playout_features<7, 12>(to_play, mv);
+        }
+        else
+        {
+            m_bd.play<22, 44>(to_play, mv);
+            update_playout_features<22, 44>(to_play, mv);
+        }
+    }
+    else
+    {
+        ++m_nu_passes;
+        m_bd.set_to_play(to_play.get_next(m_nu_colors));
+    }
+    if (log_simulations)
+        LIBBOARDGAME_LOG(m_bd);
+}
+
 inline void State::play_playout(Move mv)
 {
     auto to_play = m_bd.get_to_play();
@@ -470,8 +504,11 @@ inline void State::update_playout_features(Color c, Move mv)
     auto& info = get_move_info<MAX_SIZE>(mv);
     for (Color i : Color::Range(m_nu_colors))
         m_playout_features[i].set_forbidden(info);
-    m_playout_features[c].set_forbidden<MAX_ADJ_ATTACH>(
-                get_move_info_ext<MAX_ADJ_ATTACH>(mv));
+    if (MAX_SIZE == 7) // Nexos
+        LIBBOARDGAME_ASSERT(get_move_info_ext<MAX_ADJ_ATTACH>(mv).size_adj_points == 0);
+    else
+        m_playout_features[c].set_forbidden<MAX_ADJ_ATTACH>(
+                    get_move_info_ext<MAX_ADJ_ATTACH>(mv));
 }
 
 template<unsigned MAX_SIZE>
