@@ -19,8 +19,6 @@
 namespace libpentobi_mcts {
 namespace util {
 
-using libboardgame_mcts::Node;
-using libboardgame_mcts::Tree;
 using libboardgame_sgf::Writer;
 using libpentobi_base::boardutil::write_setup;
 using libpentobi_base::sgf_util::get_color_id;
@@ -35,12 +33,14 @@ void dump_tree_recurse(Writer& writer, Variant variant,
 {
     ostringstream comment;
     comment << "Visits: " << node.get_visit_count()
-            << "\nVal: " << node.get_value()
-            << "\nCnt: " << node.get_value_count();
+            << "\nPrior: " << node.get_move_prior()
+            << "\nVal:   " << node.get_value()
+            << "\nCnt:   " << node.get_value_count();
     writer.write_property("C", comment.str());
     writer.end_node();
     Color next_to_play = to_play.get_next(get_nu_colors(variant));
     vector<const Search::Node*> children;
+    children.reserve(node.get_nu_children());
     for (auto& i : tree.get_children(node))
         children.push_back(&i);
     sort(children.begin(), children.end(), compare_node);
