@@ -8,16 +8,12 @@
 
 #include <iostream>
 #include "libboardgame_sgf/TreeReader.h"
-#include "libboardgame_util/StringUtil.h"
 #include "libpentobi_base/NodeUtil.h"
 #include "libpentobi_gui/BoardPainter.h"
 
 using namespace std;
 using libboardgame_sgf::SgfNode;
 using libboardgame_sgf::TreeReader;
-using libboardgame_util::split;
-using libboardgame_util::trim;
-using libpentobi_base::get_board_type;
 using libpentobi_base::Geometry;
 using libpentobi_base::Grid;
 using libpentobi_base::PieceSet;
@@ -37,18 +33,22 @@ void handleSetup(const char* id, Color c, const SgfNode& node,
         return;
     for (auto& s : node.get_multi_property(id))
     {
-        if (trim(s).empty())
-            continue;
-        vector<string> v = split(s, ',');
-        ++currentPieceId;
-        for (const string& p_str : v)
+        auto begin = s.begin();
+        auto end = begin;
+        while (true)
         {
+            while (end != s.end() && *end != ',')
+                ++end;
             Point p;
-            if (geo.from_string(p_str, p))
+            if (geo.from_string(begin, end, p))
             {
                 pointState[p] = PointState(c);
                 pieceId[p] = currentPieceId;
             }
+            if (end == s.end())
+                break;
+            ++end;
+            begin = end;
         }
     }
 }
@@ -61,17 +61,22 @@ void handleSetupEmpty(const SgfNode& node, const Geometry& geo,
         return;
     for (auto& s : node.get_multi_property("AE"))
     {
-        if (trim(s).empty())
-            continue;
-        vector<string> v = split(s, ',');
-        for (const auto& p_str : v)
+        auto begin = s.begin();
+        auto end = begin;
+        while (true)
         {
+            while (end != s.end() && *end != ',')
+                ++end;
             Point p;
-            if (geo.from_string(p_str, p))
+            if (geo.from_string(begin, end, p))
             {
                 pointState[p] = PointState::empty();
                 pieceId[p] = 0;
             }
+            if (end == s.end())
+                break;
+            ++end;
+            begin = end;
         }
     }
 }
@@ -122,7 +127,7 @@ bool getFinalPosition(const SgfNode& root, Variant& variant,
         }
         node = node->get_first_child_or_null();
     }
-    while (node);
+    while (node != nullptr);
     return true;
 }
 
@@ -147,13 +152,10 @@ bool createThumbnail(const QString& path, int width, int height,
         cerr << "Not a valid Blokus SGF file\n";
         return false;
     }
-    QPainter painter;
-    if (! painter.begin(&image))
-        return false;
+    QPainter painter(&image);
     BoardPainter boardPainter;
     boardPainter.paintEmptyBoard(painter, width, height, variant, *geo);
     boardPainter.paintPieces(painter, pointState, pieceId);
-    painter.end();
     return true;
 }
 
