@@ -8,6 +8,7 @@
 #include <config.h>
 #endif
 
+#include <QApplication>
 #include <QCommandLineParser>
 #include <QFileInfo>
 #include <QLibraryInfo>
@@ -15,7 +16,6 @@
 #include <QSettings>
 #include <QStyle>
 #include <QTranslator>
-#include "Application.h"
 #include "MainWindow.h"
 
 #ifdef Q_OS_WIN
@@ -56,11 +56,9 @@ void redirectStdErr()
 int main(int argc, char* argv[])
 {
     LogInitializer log_initializer;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    Application app(argc, argv);
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QApplication app(argc, argv);
     app.setOrganizationName("Pentobi");
     app.setApplicationName("Pentobi");
     try
@@ -69,44 +67,36 @@ int main(int argc, char* argv[])
         // Windows 7 with Qt 4.8. We don't want that.
         app.setStyleSheet("QStatusBar::item { border: 0px solid black }");
 
-        // Allow the user to override installation paths with a config file in
-        // the directory of the executable to test it without installation
+#ifdef PENTOBI_HELP_DIR
+        QString helpDir = PENTOBI_HELP_DIR;
+#else
         QString helpDir;
+#endif
+#ifdef PENTOBI_BOOKS_DIR
+        QString booksDir = PENTOBI_BOOKS_DIR;
+#else
         QString booksDir;
+#endif
+#ifdef PENTOBI_TRANSLATIONS
+        QString translationsPentobiDir = PENTOBI_TRANSLATIONS;
+        QString translationsLibPentobiGuiDir = PENTOBI_TRANSLATIONS;
+#else
         QString translationsPentobiDir;
         QString translationsLibPentobiGuiDir;
-        QString appDir = app.applicationDirPath();
-#ifdef PENTOBI_HELP_DIR
-        helpDir = PENTOBI_HELP_DIR;
 #endif
-        if (helpDir.isEmpty())
-            helpDir = appDir + "/help";
-#ifdef PENTOBI_BOOKS_DIR
-        booksDir = PENTOBI_BOOKS_DIR;
-#endif
-        if (booksDir.isEmpty())
-            booksDir = appDir + "/books";
-#ifdef PENTOBI_TRANSLATIONS
-        translationsPentobiDir = PENTOBI_TRANSLATIONS;
-        translationsLibPentobiGuiDir = PENTOBI_TRANSLATIONS;
-#endif
-        if (translationsPentobiDir.isEmpty())
-            translationsPentobiDir = appDir + "/translations";
-        if (translationsLibPentobiGuiDir.isEmpty())
-            translationsLibPentobiGuiDir = appDir + "/translations";
-        QString overrideConfigFile = appDir + "/pentobi.conf";
+        // Allow the user to override installation paths with a config file in
+        // the directory of the executable to test it without installation
+        auto overrideConfigFile = app.applicationDirPath() + "/pentobi.conf";
         if (QFileInfo::exists(overrideConfigFile))
         {
             QSettings settings(overrideConfigFile, QSettings::IniFormat);
-            helpDir = settings.value("HelpDir", helpDir).toString();
-            booksDir = settings.value("BooksDir", booksDir).toString();
+            helpDir = settings.value("HelpDir").toString();
+            booksDir = settings.value("BooksDir").toString();
             translationsPentobiDir =
-                settings.value("TranslationsPentobiDir",
-                               translationsPentobiDir).toString();
+                settings.value("TranslationsPentobiDir").toString();
             translationsLibPentobiGuiDir =
-                settings.value("TranslationsLibPentobiGuiDir",
-                               translationsLibPentobiGuiDir).toString();
-            }
+                settings.value("TranslationsLibPentobiGuiDir").toString();
+        }
 
         QTranslator qtTranslator;
         QString qtTranslationPath =
@@ -128,16 +118,21 @@ int main(int argc, char* argv[])
                                           "Set maximum level to <n>.", "n",
                                           QString::number(maxSupportedLevel));
         parser.addOption(optionMaxLevel);
-        QCommandLineOption optionNoBook("nobook");
+        QCommandLineOption optionNoBook("nobook", "Do not use opening books.");
         parser.addOption(optionNoBook);
-        QCommandLineOption optionNoDelay("nodelay");
+        QCommandLineOption optionNoDelay(
+                    "nodelay", "Do not delay fast computer moves.");
         parser.addOption(optionNoDelay);
         QCommandLineOption optionSeed("seed", "Set random seed to <n>.", "n");
         parser.addOption(optionSeed);
         QCommandLineOption optionThreads("threads", "Use <n> threads.", "n");
         parser.addOption(optionThreads);
-        QCommandLineOption optionVerbose("verbose");
+        QCommandLineOption optionVerbose(
+                    "verbose", "Print logging information to standard error.");
         parser.addOption(optionVerbose);
+        parser.addPositionalArgument("file.blksgf",
+                                     "Blokus SGF file to open (optional).");
+        parser.addHelpOption();
         parser.process(app);
         bool ok;
         auto maxLevel = parser.value(optionMaxLevel).toUInt(&ok);
@@ -180,8 +175,8 @@ int main(int argc, char* argv[])
             variant = Variant::duo;
         try
         {
-            MainWindow mainWindow(variant, initialFile, helpDir, maxLevel,
-                                  booksDir, noBook, threads);
+            MainWindow mainWindow(nullptr, variant, initialFile, helpDir,
+                                  maxLevel, booksDir, noBook, threads);
             if (parser.isSet(optionNoDelay))
                 mainWindow.setNoDelay();
             mainWindow.show();
