@@ -38,7 +38,6 @@ class ScoreDisplay;
 using namespace std;
 using libboardgame_sgf::SgfNode;
 using libboardgame_base::Transform;
-using libboardgame_util::ArrayList;
 using libboardgame_util::RandomGenerator;
 using libpentobi_base::Board;
 using libpentobi_base::ColorMap;
@@ -60,13 +59,14 @@ class MainWindow
     Q_OBJECT
 
 public:
-    explicit MainWindow(Variant variant, const QString& initialFile = "",
+    explicit MainWindow(QWidget* parent, Variant variant,
+                        const QString& initialFile = "",
                         const QString& helpDir = "",
                         unsigned maxLevel = Player::max_supported_level,
                         const QString& booksDir = "", bool noBook = false,
                         unsigned nuThreads = 0);
 
-    ~MainWindow();
+    ~MainWindow() override;
 
     bool eventFilter(QObject* object, QEvent* event) override;
 
@@ -145,9 +145,9 @@ public slots:
 
     void open();
 
-    bool open(istream& in);
+    bool openStream(istream& in);
 
-    bool open(const QString& file, bool isTemporary = false);
+    bool openFile(const QString& file, bool isTemporary = false);
 
     void openFromClipboard();
 
@@ -177,7 +177,8 @@ public slots:
 
     void selectPiece(Color c, Piece piece);
 
-    void selectPiece(Color c, Piece piece, const Transform* transform);
+    void selectTransformedPiece(Color c, Piece piece,
+                                const Transform* transform);
 
     void setLevel(unsigned level);
 
@@ -605,11 +606,11 @@ private:
 
     void leaveSetupMode();
 
-    void play(Color c, Move mv);
+    void playMove(Color c, Move mv);
 
     void restoreLevel(Variant variant);
 
-    bool save(const QString& file);
+    bool saveFile(const QString& file);
 
     void searchCallback(double elapsedSeconds, double remainingSeconds);
 
@@ -680,12 +681,8 @@ private slots:
 
     void noMoveAnnotation(bool checked);
 
-    void openCheckSave(const QString& file);
-
     void openRecentFile();
 
-    void orientationDisplayColorClicked(Color c);
-
     void rememberFile(const QString& file);
 
     void rememberDir(const QString& file);
@@ -708,18 +705,8 @@ private slots:
 
     void showComment(bool checked);
 
-    void toolBarNoText(bool checked);
-
     void toolBarText(const QString& key, Qt::ToolButtonStyle style);
 
-    void toolBarTextBesideIcons(bool checked);
-
-    void toolBarTextBelowIcons(bool checked);
-
-    void toolBarTextOnly(bool checked);
-
-    void toolBarTextSystem(bool checked);
-
     void veryBadMove(bool checked);
 
     void veryGoodMove(bool checked);
