@@ -28,15 +28,14 @@ RatedGamesList::RatedGamesList(QWidget* parent)
     setSelectionBehavior(QAbstractItemView::SelectRows);
     setAlternatingRowColors(true);
     m_model = new QStandardItemModel(this);
-    setModel(m_model);
-    connect(this, SIGNAL(doubleClicked(const QModelIndex&)),
-            SLOT(activateGame(const QModelIndex&)));
+    QTableView::setModel(m_model);
+    connect(this, &RatedGamesList::doubleClicked, this, &RatedGamesList::activateGame);
 }
 
 void RatedGamesList::activateGame(const QModelIndex& index)
 {
     auto item = m_model->item(index.row(), 0);
-    if (! item)
+    if (item == nullptr)
         return;
     bool ok;
     unsigned n = item->text().toUInt(&ok);
