@@ -39,7 +39,7 @@ Engine::Engine(Variant variant, unsigned level, bool use_book,
     add("version", &Engine::cmd_version);
 }
 
-Engine::~Engine() = default;
+Engine::~Engine() = default; // Non-inline to avoid GCC -Winline warning
 
 void Engine::cmd_get_value(Response& response)
 {
@@ -52,6 +52,7 @@ void Engine::cmd_move_values(Response& response)
     auto& tree = search.get_tree();
     auto& bd = get_board();
     vector<const Search::Node*> children;
+    children.reserve(tree.get_root().get_nu_children());
     for (auto& i : tree.get_root_children())
         children.push_back(&i);
     sort(children.begin(), children.end(), libpentobi_mcts::util::compare_node);
@@ -68,7 +69,7 @@ void Engine::cmd_name(Response& response)
     response.set("Pentobi");
 }
 
-void Engine::cmd_save_tree(const Arguments& args)
+void Engine::cmd_save_tree(Arguments args)
 {
     auto& search = get_search();
     if (! search.get_last_history().is_valid())
@@ -82,7 +83,7 @@ void Engine::cmd_save_tree(const Arguments& args)
     because it has lower memory requirements (only one engine needed), process
     switches between the engines are avoided and parts of the search tree can
     be reused between moves of different players. */
-void Engine::cmd_selfplay(const Arguments& args)
+void Engine::cmd_selfplay(Arguments args)
 {
     args.check_size(2);
     auto nu_games = args.parse<int>(0);
@@ -117,7 +118,7 @@ void Engine::cmd_selfplay(const Arguments& args)
     }
 }
 
-void Engine::cmd_param(const Arguments& args, Response& response)
+void Engine::cmd_param(Arguments args, Response& response)
 {
     auto& p = get_mcts_player();
     auto& s = get_search();
@@ -190,7 +191,7 @@ void Engine::create_player(Variant variant, unsigned level,
                            const string& books_dir, unsigned nu_threads)
 {
     auto max_level = level;
-    m_player.reset(new Player(variant, max_level, books_dir, nu_threads));
+    m_player = make_unique<Player>(variant, max_level, books_dir, nu_threads);
     get_mcts_player().set_level(level);
     set_player(*m_player);
 }
