@@ -26,19 +26,19 @@ class Engine
     : public libpentobi_base::Engine
 {
 public:
-    Engine(Variant variant, unsigned level = 5,
-           bool use_book = true, const string& books_dir = "",
-           unsigned nu_threads = 0);
+    explicit Engine(Variant variant, unsigned level = 5,
+                    bool use_book = true, const string& books_dir = "",
+                    unsigned nu_threads = 0);
 
-    ~Engine();
+    ~Engine() override;
 
-    void cmd_param(const Arguments&, Response&);
-    void cmd_get_value(Response&);
-    void cmd_move_values(Response&);
-    void cmd_name(Response&);
-    void cmd_selfplay(const Arguments&);
-    void cmd_save_tree(const Arguments&);
-    void cmd_version(Response&);
+    void cmd_param(Arguments args, Response& response);
+    void cmd_get_value(Response& response);
+    void cmd_move_values(Response& response);
+    void cmd_name(Response& response);
+    void cmd_selfplay(Arguments args);
+    void cmd_save_tree(Arguments args);
+    void cmd_version(Response& response);
 
     Player& get_mcts_player();
 
