@@ -19,7 +19,8 @@ class PentobiThumbCreator
     Q_OBJECT
 
 public:
-    virtual ~PentobiThumbCreator();
+    using QObject::QObject;
+
 
     bool create(const QString& path, int width, int height,
                 QImage& image) override;
