@@ -24,7 +24,7 @@
 #include "libpentobi_base/TreeUtil.h"
 
 using namespace std;
-using libboardgame_sgf::InvalidTree;
+using libboardgame_sgf::SgfError;
 using libboardgame_sgf::TreeReader;
 using libboardgame_sgf::util::back_to_main_variation;
 using libboardgame_sgf::util::beginning_of_branch;
@@ -159,7 +159,7 @@ GameMove* GameModel::addEmpty(const QPoint& pos)
         return nullptr;
     auto x = static_cast<unsigned>(pos.x());
     auto y = static_cast<unsigned>(pos.y());
-    if (! geo.is_onboard(CoordPoint(x, y)))
+    if (! geo.is_onboard(x, y))
         return nullptr;
     auto p = geo.get_point(x, y);
     auto s = bd.get_point_state(p);
@@ -205,7 +205,7 @@ void GameModel::addSetup(PieceModel* pieceModel, QPointF coord)
     {
         m_game.add_setup(c, mv);
     }
-    catch (const InvalidTree&)
+    catch (const SgfError&)
     {
     }
     setSetupPlayer();
@@ -425,7 +425,7 @@ bool GameModel::findMove(const PieceModel& pieceModel, const QString& state,
     {
         int x = p.x + offX;
         int y = p.y + offY;
-        if (! geo.is_onboard(CoordPoint(x, y)))
+        if (! geo.is_onboard(x, y))
             return false;
         points.push_back(geo.get_point(x, y));
     }
@@ -454,17 +454,23 @@ bool GameModel::findNextCommentContinueFromRoot()
 
 QString GameModel::getPlayerString(int player)
 {
-    bool isMulticolor = (m_nuColors > m_nuPlayers
-                         && m_game.get_variant() != Variant::classic_3);
+    auto variant = m_game.get_variant();
+    bool isMulticolor = (m_nuColors > m_nuPlayers && variant != Variant::classic_3);
     switch (player) {
     case 0:
         if (isMulticolor)
             return tr("Blue/Red");
+        else if (variant == Variant::duo)
+            return tr("Purple");
+        else if (variant == Variant::junior)
+            return tr("Green");
         else
             return tr("Blue");
     case 1:
         if (isMulticolor)
             return tr("Yellow/Green");
+        else if (variant == Variant::duo || variant == Variant::junior)
+            return tr("Orange");
         else if (m_nuColors == 2)
             return tr("Green");
         else
@@ -502,6 +508,33 @@ QList<PieceModel*>& GameModel::getPieceModels(Color c)
 QString GameModel::getResultMessage()
 {
     auto& bd = getBoard();
+    auto variant = bd.get_variant();
+    if (variant == Variant::duo)
+    {
+        auto score = m_points0 - m_points1;
+        if (score == 1)
+            return tr("Purple wins with 1 point.");
+        if (score > 0)
+            return tr("Purple wins with %L1 points.").arg(score);
+        if (score == -1)
+            return tr("Orange wins with 1 point.");
+        if (score < 0)
+            return tr("Orange wins with %L1 points.").arg(-score);
+        return tr("Game ends in a tie.");
+    }
+    if (variant == Variant::junior)
+    {
+        auto score = m_points0 - m_points1;
+        if (score == 1)
+            return tr("Green wins with 1 point.");
+        if (score > 0)
+            return tr("Green wins with %L1 points.").arg(score);
+        if (score == -1)
+            return tr("Orange wins with 1 point.");
+        if (score < 0)
+            return tr("Orange wins with %L1 points.").arg(-score);
+        return tr("Game ends in a tie.");
+    }
     bool breakTies = (bd.get_piece_set() == PieceSet::callisto);
     if (m_nuColors == 2)
     {
@@ -675,7 +708,7 @@ void GameModel::gotoNode(const SgfNode& node)
     {
         m_game.goto_node(node);
     }
-    catch (const InvalidTree&)
+    catch (const SgfError&)
     {
     }
     updateProperties();
@@ -855,10 +888,12 @@ bool GameModel::openStream(istream& in)
         m_textCodec = QTextCodec::codecForName(m_game.get_charset().c_str());
     if (! m_textCodec)
     {
-        qWarning() << "GameModel: unknown codec '"
-                   << QString::fromLocal8Bit(charSet.c_str()) << "'";
         m_textCodec = QTextCodec::codecForName("ISO 8859-1");
+        m_lastInputOutputError = QString(tr("File has unsupported character set."));
+        result = false;
     }
+    if (! result)
+        m_game.init();
     auto variant = to_string_id(m_game.get_variant());
     if (variant != m_gameVariant)
         initGameVariant(m_game.get_variant());
@@ -1364,7 +1399,7 @@ void GameModel::updatePieces()
     auto& tree = m_game.get_tree();
     // We need to loop forward through the moves to ensure the persistence of
     // the GUI pieces, see comment in updatePiece()
-    ArrayList<const SgfNode*, Board::max_game_moves> nodes;
+    ArrayList<const SgfNode*, Board::max_moves> nodes;
     auto node = &m_game.get_current();
     do
     {
