@@ -8,13 +8,17 @@
 #define PENTOBI_QML_PLAYER_MODEL_H
 
 #include <QFutureWatcher>
-#include "GameModel.h"
 #include "libpentobi_mcts/Player.h"
 
+class GameModel;
+class GameMove;
+
 using namespace std;
+using libpentobi_base::Color;
+using libpentobi_base::Move;
+using libpentobi_base::Variant;
 using libpentobi_mcts::Player;
 using libpentobi_mcts::Search;
-using libpentobi_base::Variant;
 
 //-----------------------------------------------------------------------------
 
@@ -106,12 +110,12 @@ private:
 
     Player m_player;
 
-    QFutureWatcher<GenMoveResult> m_genMoveWatcher;
+    QFutureWatcher<GenMoveResult> m_watcher;
 
 
     GenMoveResult asyncGenMove(GameModel* gm, Color c, unsigned genMoveId);
 
-    bool getKey(const QString& gameVariant, QString& key);
+    bool getLevelKey(const QString& gameVariant, QString& key);
 
     void loadBook(Variant variant);
 
