@@ -71,7 +71,7 @@ Output::~Output()
 void Output::add_result(unsigned n, float result, const Board& bd,
                         unsigned player_black, double cpu_black,
                         double cpu_white, const string& sgf,
-                        const array<bool, Board::max_game_moves>& is_real_move)
+                        const array<bool, Board::max_moves>& is_real_move)
 {
     {
         lock_guard<mutex> lock(m_mutex);
