@@ -18,6 +18,7 @@
 using libboardgame_sgf::SgfNode;
 using libboardgame_sgf::TreeReader;
 using libboardgame_sgf::TreeWriter;
+using libboardgame_util::ArrayList;
 using libpentobi_base::get_transforms;
 using libpentobi_base::ColorMove;
 using libpentobi_base::MovePoints;
@@ -63,8 +64,8 @@ void add(PentobiTree& tree, const SgfNode& node, bool is_player_black,
     tree.set_comment(node, out.str());
 }
 
-bool compare_sequence(ArrayList<ColorMove, Board::max_game_moves>& s1,
-                      ArrayList<ColorMove, Board::max_game_moves>& s2)
+bool compare_sequence(ArrayList<ColorMove, Board::max_moves>& s1,
+                      ArrayList<ColorMove, Board::max_moves>& s2)
 {
     LIBBOARDGAME_ASSERT(s1.size() == s2.size());
     for (unsigned i = 0; i < s1.size(); ++i)
@@ -72,7 +73,7 @@ bool compare_sequence(ArrayList<ColorMove, Board::max_game_moves>& s1,
         LIBBOARDGAME_ASSERT(s1[i].color == s2[i].color);
         if (s1[i].move.to_int() < s2[i].move.to_int())
             return true;
-        else if (s1[i].move.to_int() > s2[i].move.to_int())
+        if (s1[i].move.to_int() > s2[i].move.to_int())
             return false;
     }
     return false;
@@ -104,19 +105,19 @@ OutputTree::OutputTree(Variant variant)
     get_transforms(variant, m_transforms, m_inv_transforms);
 }
 
-OutputTree::~OutputTree() = default;
+OutputTree::~OutputTree() = default; // Non-inline to avoid GCC -Winline warning
 
 void OutputTree::add_game(const Board& bd, unsigned player_black, float result,
-                        const array<bool, Board::max_game_moves>& is_real_move)
+                          const array<bool, Board::max_moves>& is_real_move)
 {
     if (bd.has_setup())
         throw runtime_error("OutputTree: setup not supported");
 
     // Find the canonical representation
-    ArrayList<ColorMove, Board::max_game_moves> sequence;
+    ArrayList<ColorMove, Board::max_moves> sequence;
     for (auto& transform : m_transforms)
     {
-        ArrayList<ColorMove, Board::max_game_moves> s;
+        ArrayList<ColorMove, Board::max_moves> s;
         for (unsigned i = 0; i < bd.get_nu_moves(); ++i)
         {
             auto mv = bd.get_move(i);
@@ -143,7 +144,7 @@ void OutputTree::add_game(const Board& bd, unsigned player_black, float result,
         else
             player = c.to_int() % bd.get_nu_players();
         auto child = m_tree.find_child_with_move(*node, mv);
-        if (! child)
+        if (child == nullptr)
         {
             child = &m_tree.create_new_child(*node);
             m_tree.set_move(*child, mv);
@@ -184,7 +185,7 @@ void OutputTree::generate_move(bool is_player_black, const Board& bd,
         ColorMove transformed_mv(mv.color,
                                  get_transformed(bd, mv.move, transform));
         auto child = m_tree.find_child_with_move(*node, transformed_mv);
-        if (! child)
+        if (child == nullptr)
             return;
         node = child;
     }
@@ -199,7 +200,7 @@ void OutputTree::generate_move(bool is_player_black, const Board& bd,
         play_real = true;
         return;
     }
-    unsigned random = static_cast<unsigned>(distribution(m_random) * sum);
+    auto random = static_cast<unsigned>(distribution(m_random) * sum);
     sum = 0;
     for (auto& i : node->get_children())
     {
