@@ -13,7 +13,6 @@
 
 using namespace std;
 using libboardgame_base::PointTransform;
-using libboardgame_util::ArrayList;
 using libpentobi_base::Board;
 using libpentobi_base::Color;
 using libpentobi_base::Move;
@@ -58,10 +57,11 @@ public:
 
     /** Add the moves of a game to the tree and update the move counters. */
     void add_game(const Board& bd, unsigned player_black, float result,
-                  const array<bool, Board::max_game_moves>& is_real_move);
+                  const array<bool, Board::max_moves>& is_real_move);
 
 private:
-    typedef libboardgame_base::PointTransform<Point> PointTransform;
+    using PointTransform = libboardgame_base::PointTransform<Point>;
+
 
     PentobiTree m_tree;
 
