@@ -12,14 +12,11 @@
 
 #include "libboardgame_sgf/Writer.h"
 #include "libboardgame_util/Log.h"
-#include "libboardgame_util/StringUtil.h"
 #include "libpentobi_base/ScoreUtil.h"
 
 using libboardgame_sgf::Writer;
-using libboardgame_util::trim;
 using libpentobi_base::get_multiplayer_result;
 using libpentobi_base::Move;
-using libpentobi_base::PieceSet;
 using libpentobi_base::ScoreType;
 
 //-----------------------------------------------------------------------------
@@ -105,7 +102,7 @@ void TwoGtp::play_game(unsigned game_number)
     sgf.write_property("GM", to_string(m_variant));
     sgf.write_property("GN", game_number);
     sgf.end_node();
-    array<bool, Board::max_game_moves> is_real_move;
+    array<bool, Board::max_moves> is_real_move;
     unsigned player;
     while (! m_bd.is_game_over())
     {
