@@ -16,8 +16,8 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-typedef libboardgame_base::Point<19 * 19, 19, 19, unsigned short> Point;
-typedef libboardgame_base::Marker<Point> Marker;
+using Point = libboardgame_base::Point<19 * 19, 19, 19, unsigned short>;
+using Marker = libboardgame_base::Marker<Point>;
 
 //-----------------------------------------------------------------------------
 
