@@ -17,8 +17,8 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-typedef libboardgame_base::Point<19 * 19, 19, 19, unsigned short> Point;
-typedef libboardgame_base::RectGeometry<Point> RectGeometry;
+using Point = libboardgame_base::Point<19 * 19, 19, 19, unsigned short>;
+using RectGeometry = libboardgame_base::RectGeometry<Point>;
 
 //-----------------------------------------------------------------------------
 
