@@ -19,7 +19,7 @@ using namespace std;
 LIBBOARDGAME_TEST_CASE(libboardgame_mcts_node_add_value)
 {
     libboardgame_mcts::Node<int, float, true> node;
-    node.init(0, 0.5, 0);
+    node.init(0, 0.5, 0, 1);
     node.add_value(5);
     LIBBOARDGAME_CHECK_CLOSE(node.get_value(), 5., 1e-4);
     node.add_value(2);
@@ -29,7 +29,7 @@ LIBBOARDGAME_TEST_CASE(libboardgame_mcts_node_add_value)
 LIBBOARDGAME_TEST_CASE(libboardgame_mcts_node_add_value_remove_loss)
 {
     libboardgame_mcts::Node<int, float, true> node;
-    node.init(0, 0.5, 0);
+    node.init(0, 0.5, 0, 1);
     node.add_value(5);
     LIBBOARDGAME_CHECK_CLOSE(node.get_value(), 5., 1e-4);
     node.add_value(0);
